#[doc(hidden)]pub trait BikeshedGuaranteedNoDrop { }🔬This is a nightly-only experimental API. (
bikeshed_guaranteed_no_drop)Expand description
Marker trait for the types that are allowed in union fields and unsafe binder types.
Implemented for:
&T,&mut Tfor allT,ManuallyDrop<T>for allT,- tuples and arrays whose elements implement
BikeshedGuaranteedNoDrop, - or otherwise, all types that are
Copy.
Notably, this doesn’t include all trivially-destructible types for semver reasons.
Bikeshed name for now. This trait does not do anything other than reflect the set of types that are allowed within unions for field validity.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.