Freeze

Trait Freeze 

pub unsafe auto trait Freeze { }
🔬This is a nightly-only experimental API. (freeze #121675)
Used to determine whether a type contains any UnsafeCell internally, but not through an indirection. This affects, for example, whether a static of that type is placed in read-only static memory or writable static memory. This can be used to declare that a constant with a generic type will not contain interior mutability, and subsequently allow placing the constant behind references.

Safety

This trait is a core part of the language, it is just expressed as a trait in libcore for convenience. Do not implement it for other types.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Auto implementors



impl Freeze for Abi



impl Freeze for AddrKind



impl Freeze for AddrParseError



impl Freeze for AesOutput



impl Freeze for core::mem::alignment::Alignment



impl Freeze for core::fmt::Alignment



impl Freeze for AlignmentEnum



impl Freeze for AllocError



impl Freeze for AlwaysEscaped



impl Freeze for Array



impl Freeze for AsciiChar



impl Freeze for Assume



impl Freeze for AtomicOrdering



impl Freeze for BasicBlock



impl Freeze for BiasedFp



impl Freeze for Big8x3



impl Freeze for Big32x40



impl Freeze for BorrowError



impl Freeze for BorrowMutError



impl Freeze for BorrowedBufDebug



impl Freeze for ByteNeedle



impl Freeze for ByteStr



impl Freeze for BytesIsNotEmpty



impl Freeze for CStr



impl Freeze for CaseMappingIter



impl Freeze for CharCase



impl Freeze for CharErrorKind



impl Freeze for CharEscapeDebug



impl Freeze for CharEscapeDefault



impl Freeze for CharEscapeUnicode



impl Freeze for CharTryFromError



impl Freeze for CodePointInner



impl Freeze for Const



impl Freeze for CpuidResult



impl Freeze for DebugAsHex



impl Freeze for Decimal



impl Freeze for DecimalSeq



impl Freeze for DecodeUtf16Error



impl Freeze for Decoded



impl Freeze for Direction



impl Freeze for DriftsortRun



impl Freeze for Duration



impl Freeze for DynTrait



impl Freeze for DynTraitPredicate



impl Freeze for core::io::util::Empty



impl Freeze for EmptyNeedle



impl Freeze for EncodeKey128Output



impl Freeze for EncodeKey256Output



impl Freeze for core::io::error::Error



impl Freeze for core::fmt::Error



impl Freeze for ErrorKind



impl Freeze for EscapeByte



impl Freeze for core::char::EscapeDebug



impl Freeze for EscapeDebugExtArgs



impl Freeze for core::ascii::EscapeDefault



impl Freeze for core::char::EscapeDefault



impl Freeze for core::char::EscapeUnicode



impl Freeze for FieldId



impl Freeze for FloatErrorKind



impl Freeze for FnPtr



impl Freeze for FormattingOptions



impl Freeze for FpCategory



impl Freeze for FromBytesUntilNulError



impl Freeze for FromBytesWithNulError



impl Freeze for FullDecoded



impl Freeze for Generic



impl Freeze for GenericType



impl Freeze for GetDisjointMutError



impl Freeze for I32NotAllOnes



impl Freeze for I64NotAllOnes



impl Freeze for IndexRange



impl Freeze for IntErrorKind



impl Freeze for Internal



impl Freeze for IpAddr



impl Freeze for Ipv4Addr



impl Freeze for Ipv6Addr



impl Freeze for Ipv6MulticastScope



impl Freeze for IsAsciiWhitespace



impl Freeze for IsNotEmpty



impl Freeze for IsWhitespace



impl Freeze for L1Lut



impl Freeze for L2Lut



impl Freeze for Last



impl Freeze for Layout



impl Freeze for LayoutError



impl Freeze for Lifetime



impl Freeze for LinesMap



impl Freeze for LocalWaker



impl Freeze for Locality



impl Freeze for MatchOnly



impl Freeze for MaybeEscaped



impl Freeze for Nanoseconds



impl Freeze for NeverShortCircuitResidual



impl Freeze for NonZeroCharInner



impl Freeze for NonZeroI8Inner



impl Freeze for NonZeroI16Inner



impl Freeze for NonZeroI32Inner



impl Freeze for NonZeroI64Inner



impl Freeze for NonZeroI128Inner



impl Freeze for NonZeroIsizeInner



impl Freeze for NonZeroU8Inner



impl Freeze for NonZeroU16Inner



impl Freeze for NonZeroU32Inner



impl Freeze for NonZeroU64Inner



impl Freeze for NonZeroU128Inner



impl Freeze for NonZeroUsizeInner



impl Freeze for OneSidedRangeBound



impl Freeze for core::cmp::Ordering



impl Freeze for core::sync::atomic::Ordering



impl Freeze for PadAdapterState



impl Freeze for ParseBoolError



impl Freeze for ParseCharError



impl Freeze for ParseFloatError



impl Freeze for ParseIntError



impl Freeze for PhantomPinned



impl Freeze for Pointer



impl Freeze for PostPadding



impl Freeze for core::unicode::unicode_data::conversions::Range



impl Freeze for RangeFull



impl Freeze for RawWaker



impl Freeze for RawWakerVTable



impl Freeze for Reference



impl Freeze for RejectAndMatch



impl Freeze for core::io::util::Repeat



impl Freeze for Repr



impl Freeze for ReturnToArg



impl Freeze for SearchStep



impl Freeze for SeekFrom



impl Freeze for ShortOffsetRunHeader



impl Freeze for core::num::imp::flt2dec::Sign



impl Freeze for core::fmt::Sign



impl Freeze for SimdAlign



impl Freeze for Sink



impl Freeze for Sip13Rounds



impl Freeze for Sip24Rounds



impl Freeze for SipHasher



impl Freeze for SipHasher24



impl Freeze for Slice



impl Freeze for SocketAddr



impl Freeze for SocketAddrV4



impl Freeze for SocketAddrV6



impl Freeze for core::hash::sip::State



impl Freeze for Str



impl Freeze for StrSearcherImpl



impl Freeze for ToCasefold



impl Freeze for ToLowercase



impl Freeze for ToTitlecase



impl Freeze for ToUppercase



impl Freeze for Trait



impl Freeze for TryCaptureWithDebug



impl Freeze for TryCaptureWithoutDebug



impl Freeze for TryFromCharError



impl Freeze for TryFromFloatSecsError



impl Freeze for TryFromFloatSecsErrorKind



impl Freeze for TryFromIntError



impl Freeze for TryFromSliceError



impl Freeze for TwoWaySearcher



impl Freeze for Type



impl Freeze for TypeId



impl Freeze for TypeKind



impl Freeze for U32NotAllOnes



impl Freeze for U64NotAllOnes



impl Freeze for UnsafeBytesToStr



impl Freeze for UnwindActionArg



impl Freeze for UnwindTerminateReason



impl Freeze for UsizeNoHighBit



impl Freeze for Utf8BoundaryError



impl Freeze for Utf8Error



impl Freeze for VaListInner



impl Freeze for VariantId



impl Freeze for Waker



impl Freeze for WideAesOutput



impl Freeze for __m128



impl Freeze for __m256



impl Freeze for __m512



impl Freeze for __m128bh



impl Freeze for __m128d



impl Freeze for __m128h



impl Freeze for __m128i



impl Freeze for __m256bh



impl Freeze for __m256d



impl Freeze for __m256h



impl Freeze for __m256i



impl Freeze for __m512bh



impl Freeze for __m512d



impl Freeze for __m512h



impl Freeze for __m512i



impl Freeze for __tile1024i



impl Freeze for bf16



impl Freeze for c_void



impl Freeze for iovec



impl<'a, 'b, const N: usize> Freeze for CharArrayRefSearcher<'a, 'b, N>
where <MultiCharEqPattern<&'b [char; N]> as Pattern>::Searcher<'a>: Freeze,



impl<'a, 'b> Freeze for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Freeze for DebugInner<'a, 'b>



impl<'a, 'b> Freeze for DebugList<'a, 'b>



impl<'a, 'b> Freeze for DebugMap<'a, 'b>



impl<'a, 'b> Freeze for DebugSet<'a, 'b>



impl<'a, 'b> Freeze for DebugStruct<'a, 'b>



impl<'a, 'b> Freeze for DebugTuple<'a, 'b>



impl<'a, 'b> Freeze for StrSearcher<'a, 'b>



impl<'a, A> Freeze for core::option::Iter<'a, A>
where Item<&'a A>: Freeze,



impl<'a, A> Freeze for core::option::IterMut<'a, A>



impl<'a, C> Freeze for MultiCharEqSearcher<'a, C>
where C: Freeze,



impl<'a, F> Freeze for CharPredicateSearcher<'a, F>



impl<'a, I, R> Freeze for GenericShunt<'a, I, R>
where I: Freeze, &'a mut Option<R>: Freeze,



impl<'a, I> Freeze for ByRefSized<'a, I>



impl<'a, I> Freeze for TaggedOption<'a, I>
where Option<<I as Type<'a>>::Reified>: Freeze,



impl<'a, P> Freeze for MatchIndices<'a, P>



impl<'a, P> Freeze for MatchIndicesInternal<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for Matches<'a, P>
where MatchesInternal<'a, P>: Freeze,



impl<'a, P> Freeze for MatchesInternal<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for RMatchIndices<'a, P>



impl<'a, P> Freeze for RMatches<'a, P>
where MatchesInternal<'a, P>: Freeze,



impl<'a, P> Freeze for core::str::iter::RSplit<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, P> Freeze for core::str::iter::RSplitN<'a, P>
where SplitNInternal<'a, P>: Freeze,



impl<'a, P> Freeze for RSplitTerminator<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, P> Freeze for core::str::iter::Split<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, P> Freeze for core::str::iter::SplitInclusive<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, P> Freeze for SplitInternal<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for core::str::iter::SplitN<'a, P>
where SplitNInternal<'a, P>: Freeze,



impl<'a, P> Freeze for SplitNInternal<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, P> Freeze for SplitTerminator<'a, P>
where SplitInternal<'a, P>: Freeze,



impl<'a, T, P> Freeze for ChunkBy<'a, T, P>
where &'a [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for ChunkByMut<'a, T, P>
where &'a mut [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for core::slice::iter::RSplit<'a, T, P>
where Split<'a, T, P>: Freeze,



impl<'a, T, P> Freeze for RSplitMut<'a, T, P>
where SplitMut<'a, T, P>: Freeze,



impl<'a, T, P> Freeze for core::slice::iter::RSplitN<'a, T, P>
where GenericSplitN<RSplit<'a, T, P>>: Freeze,



impl<'a, T, P> Freeze for RSplitNMut<'a, T, P>
where GenericSplitN<RSplitMut<'a, T, P>>: Freeze,



impl<'a, T, P> Freeze for core::slice::iter::Split<'a, T, P>
where &'a [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for core::slice::iter::SplitInclusive<'a, T, P>
where &'a [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for SplitInclusiveMut<'a, T, P>
where &'a mut [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for SplitMut<'a, T, P>
where &'a mut [T]: Freeze, P: Freeze,



impl<'a, T, P> Freeze for core::slice::iter::SplitN<'a, T, P>
where GenericSplitN<Split<'a, T, P>>: Freeze,



impl<'a, T, P> Freeze for SplitNMut<'a, T, P>
where GenericSplitN<SplitMut<'a, T, P>>: Freeze,



impl<'a, T, const N: usize> Freeze for ArrayWindows<'a, T, N>
where &'a [T]: Freeze,



impl<'a, T> Freeze for BorrowedCursor<'a, T>



impl<'a, T> Freeze for Chunks<'a, T>
where &'a [T]: Freeze,



impl<'a, T> Freeze for ChunksExact<'a, T>
where &'a [T]: Freeze,



impl<'a, T> Freeze for ChunksExactMut<'a, T>



impl<'a, T> Freeze for ChunksMut<'a, T>



impl<'a, T> Freeze for core::mem::maybe_uninit::Guard<'a, T>
where &'a mut [MaybeUninit<T>]: Freeze,



impl<'a, T> Freeze for core::array::Guard<'a, T>
where &'a mut [MaybeUninit<T>]: Freeze,



impl<'a, T> Freeze for GuardBack<'a, T>
where &'a mut [MaybeUninit<T>]: Freeze,



impl<'a, T> Freeze for InitializingSlice<'a, T>
where &'a mut [MaybeUninit<T>]: Freeze,



impl<'a, T> Freeze for core::slice::iter::Iter<'a, T>



impl<'a, T> Freeze for core::result::Iter<'a, T>



impl<'a, T> Freeze for core::slice::iter::IterMut<'a, T>



impl<'a, T> Freeze for core::result::IterMut<'a, T>



impl<'a, T> Freeze for RChunks<'a, T>
where &'a [T]: Freeze,



impl<'a, T> Freeze for RChunksExact<'a, T>
where &'a [T]: Freeze,



impl<'a, T> Freeze for RChunksExactMut<'a, T>
where *mut [T]: Freeze, &'a mut [T]: Freeze,



impl<'a, T> Freeze for RChunksMut<'a, T>



impl<'a, T> Freeze for Windows<'a, T>
where &'a [T]: Freeze,



impl<'a, const N: usize> Freeze for CharArraySearcher<'a, N>



impl<'a> !Freeze for Request<'a>



impl<'a> Freeze for Argument<'a>



impl<'a> Freeze for ArgumentType<'a>



impl<'a> Freeze for Arguments<'a>



impl<'a> Freeze for core::ffi::c_str::Bytes<'a>



impl<'a> Freeze for core::str::iter::Bytes<'a>



impl<'a> Freeze for CharIndices<'a>



impl<'a> Freeze for CharSearcher<'a>



impl<'a> Freeze for Chars<'a>



impl<'a> Freeze for Context<'a>



impl<'a> Freeze for ContextBuilder<'a>



impl<'a> Freeze for Debug<'a>



impl<'a> Freeze for DisplayBuffer<'a>



impl<'a> Freeze for EncodeUtf16<'a>



impl<'a> Freeze for EscapeAscii<'a>



impl<'a> Freeze for core::str::iter::EscapeDebug<'a>



impl<'a> Freeze for core::str::iter::EscapeDefault<'a>



impl<'a> Freeze for core::str::iter::EscapeUnicode<'a>



impl<'a> Freeze for ExtData<'a>



impl<'a> Freeze for Formatted<'a>



impl<'a> Freeze for Formatter<'a>



impl<'a> Freeze for core::io::io_slice::repr::IoSlice<'a>



impl<'a> Freeze for core::io::io_slice::IoSlice<'a>



impl<'a> Freeze for core::io::io_slice::repr::IoSliceMut<'a>



impl<'a> Freeze for core::io::io_slice::IoSliceMut<'a>



impl<'a> Freeze for Lines<'a>



impl<'a> Freeze for LinesAny<'a>



impl<'a> Freeze for Location<'a>



impl<'a> Freeze for PanicInfo<'a>



impl<'a> Freeze for PanicMessage<'a>



impl<'a> Freeze for Parser<'a>



impl<'a> Freeze for Part<'a>



impl<'a> Freeze for PhantomContravariantLifetime<'a>



impl<'a> Freeze for PhantomCovariantLifetime<'a>



impl<'a> Freeze for PhantomInvariantLifetime<'a>



impl<'a> Freeze for Source<'a>



impl<'a> Freeze for core::slice::ascii::SplitAsciiWhitespace<'a>



impl<'a> Freeze for core::str::iter::SplitAsciiWhitespace<'a>



impl<'a> Freeze for SplitWhitespace<'a>



impl<'a> Freeze for Utf8Chunk<'a>



impl<'a> Freeze for Utf8Chunks<'a>



impl<'a> Freeze for Utf8Pattern<'a>



impl<'a> Freeze for VaList<'a>



impl<'b, T> Freeze for core::cell::Ref<'b, T>
where NonNull<T>: Freeze, T: ?Sized,



impl<'b, T> Freeze for RefMut<'b, T>



impl<'b> Freeze for BorrowRef<'b>



impl<'b> Freeze for BorrowRefMut<'b>



impl<'buf, 'state> Freeze for PadAdapter<'buf, 'state>



impl<'data, T> Freeze for BorrowedBuf<'data, T>
where &'data mut [MaybeUninit<T>]: Freeze,



impl<'l, 'f, T, F> Freeze for Drain<'l, 'f, T, F>



impl<A, B> Freeze for core::iter::adapters::chain::Chain<A, B>
where Option<A>: Freeze, Option<B>: Freeze,



impl<A, B> Freeze for Zip<A, B>
where A: Freeze, B: Freeze,



impl<A> Freeze for core::option::IntoIter<A>
where Item<A>: Freeze,



impl<A> Freeze for Item<A>
where Option<A>: Freeze,



impl<A> Freeze for OptionFlatten<A>
where Option<A>: Freeze,



impl<A> Freeze for RangeFromIter<A>
where A: Freeze,



impl<A> Freeze for RangeInclusiveIter<A>



impl<A> Freeze for RangeIter<A>
where Range<A>: Freeze,



impl<A> Freeze for core::iter::sources::repeat::Repeat<A>
where A: Freeze,



impl<A> Freeze for RepeatN<A>



impl<B, C> Freeze for ControlFlow<B, C>
where C: Freeze, B: Freeze,



impl<C> Freeze for ErrorData<C>
where C: Freeze,



impl<C> Freeze for MultiCharEqPattern<C>
where C: Freeze,



impl<DATA> Freeze for PolymorphicIter<DATA>
where DATA: Freeze + ?Sized,



impl<Dyn> Freeze for DynMetadata<Dyn>
where PhantomData<Dyn>: Freeze, Dyn: ?Sized,



impl<E, M> Freeze for Capture<E, M>



impl<E> Freeze for Tagged<E>
where E: Freeze + ?Sized,



impl<F> !Freeze for DebugOnce<F>



impl<F> Freeze for core::iter::sources::from_fn::FromFn<F>
where F: Freeze,



impl<F> Freeze for core::fmt::builders::FromFn<F>
where F: Freeze,



impl<F> Freeze for MaybeDone<F>
where F: Freeze, <F as Future>::Output: Freeze,



impl<F> Freeze for OnceWith<F>
where Option<F>: Freeze,



impl<F> Freeze for PollFn<F>
where F: Freeze,



impl<F> Freeze for RepeatWith<F>
where F: Freeze,



impl<G> Freeze for FromCoroutine<G>
where G: Freeze,



impl<H> Freeze for BuildHasherDefault<H>
where PhantomData<fn() -> H>: Freeze,



impl<I, F, const N: usize> Freeze for MapWindows<I, F, N>
where F: Freeze, MapWindowsInner<I, N>: Freeze,



impl<I, F> Freeze for FilterMap<I, F>
where I: Freeze, F: Freeze,



impl<I, F> Freeze for Inspect<I, F>
where I: Freeze, F: Freeze,



impl<I, F> Freeze for Map<I, F>
where I: Freeze, F: Freeze,



impl<I, G> Freeze for IntersperseWith<I, G>
where G: Freeze, Option<<I as Iterator>::Item>: Freeze, I: Freeze,



impl<I, P> Freeze for Filter<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for MapWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for SkipWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for TakeWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, St, F> Freeze for Scan<I, St, F>
where I: Freeze, F: Freeze, St: Freeze,



impl<I, U, F> Freeze for FlatMap<I, U, F>
where FlattenCompat<Map<I, F>, <U as IntoIterator>::IntoIter>: Freeze,



impl<I, U> Freeze for FlattenCompat<I, U>
where Fuse<I>: Freeze, Option<U>: Freeze,



impl<I, const N: usize> Freeze for ArrayChunks<I, N>
where I: Freeze, Option<IntoIter<<I as Iterator>::Item, N>>: Freeze,



impl<I, const N: usize> Freeze for MapWindowsInner<I, N>
where I: Freeze, Option<Buffer<<I as Iterator>::Item, N>>: Freeze,



impl<I> Freeze for Cloned<I>
where I: Freeze,



impl<I> Freeze for Copied<I>
where I: Freeze,



impl<I> Freeze for Cycle<I>
where I: Freeze,



impl<I> Freeze for DecodeUtf16<I>
where I: Freeze,



impl<I> Freeze for Enumerate<I>
where I: Freeze,



impl<I> Freeze for Flatten<I>



impl<I> Freeze for FromIter<I>
where I: Freeze,



impl<I> Freeze for Fuse<I>
where Option<I>: Freeze,



impl<I> Freeze for GenericSplitN<I>
where I: Freeze,



impl<I> Freeze for Intersperse<I>
where <I as Iterator>::Item: Sized + Freeze, Option<<I as Iterator>::Item>: Freeze, I: Freeze,



impl<I> Freeze for Peekable<I>
where I: Freeze, Option<Option<<I as Iterator>::Item>>: Freeze,



impl<I> Freeze for core::error::tags::Ref<I>
where PhantomData<I>: Freeze,



impl<I> Freeze for Skip<I>
where I: Freeze,



impl<I> Freeze for StepBy<I>
where I: Freeze,



impl<I> Freeze for core::iter::adapters::take::Take<I>
where I: Freeze,



impl<Idx> Freeze for Clamp<Idx>
where Idx: Freeze,



impl<Idx> Freeze for core::ops::range::Range<Idx>
where Idx: Freeze,



impl<Idx> Freeze for core::range::Range<Idx>
where Idx: Freeze,



impl<Idx> Freeze for core::ops::range::RangeFrom<Idx>
where Idx: Freeze,



impl<Idx> Freeze for core::range::RangeFrom<Idx>
where Idx: Freeze,



impl<Idx> Freeze for core::ops::range::RangeInclusive<Idx>
where Idx: Freeze,



impl<Idx> Freeze for core::range::RangeInclusive<Idx>
where Idx: Freeze,



impl<Idx> Freeze for RangeTo<Idx>
where Idx: Freeze,



impl<Idx> Freeze for core::ops::range::RangeToInclusive<Idx>
where Idx: Freeze,



impl<Idx> Freeze for core::range::RangeToInclusive<Idx>
where Idx: Freeze,



impl<K, V> Freeze for KeyAndValue<K, V>
where K: Freeze, V: Freeze,



impl<P> Freeze for MaybeDangling<P>
where P: Freeze + ?Sized,



impl<Ptr> Freeze for Pin<Ptr>
where Ptr: Freeze,



impl<Ptr> Freeze for PinHelper<Ptr>
where Ptr: Freeze,



impl<S> Freeze for Hasher<S>
where PhantomData<S>: Freeze,



impl<T, E> Freeze for Result<T, E>
where T: Freeze, E: Freeze,



impl<T, F = fn() -> T> !Freeze for LazyCell<T, F>



impl<T, F> Freeze for DropGuard<T, F>



impl<T, F> Freeze for core::cell::lazy::State<T, F>
where F: Freeze, T: Freeze,



impl<T, F> Freeze for Successors<T, F>
where Option<T>: Freeze, F: Freeze,



impl<T, U> Freeze for core::io::util::Chain<T, U>
where T: Freeze, U: Freeze,



impl<T, const N: usize> Freeze for AlignedStorage<T, N>



impl<T, const N: usize> Freeze for Buffer<T, N>
where [[MaybeUninit<T>; N]; 2]: Freeze,



impl<T, const N: usize> Freeze for core::array::iter::IntoIter<T, N>



impl<T, const N: usize> Freeze for Mask<T, N>
where Simd<T, N>: Freeze,



impl<T, const N: usize> Freeze for core::core_arch::simd::Simd<T, N>
where [T; N]: Freeze,



impl<T, const N: usize> Freeze for core::core_simd::vector::Simd<T, N>
where [T; N]: Freeze,



impl<T, const N: usize> Freeze for SimdM<T, N>
where [T; N]: Freeze,



impl<T, const VARIANT: u32, const FIELD: u32> Freeze for FieldRepresentingType<T, VARIANT, FIELD>
where PhantomData<fn(T) -> T>: Freeze, T: ?Sized,



impl<T> !Freeze for Atomic<T>



impl<T> !Freeze for Cell<T>



impl<T> !Freeze for CovariantUnsafeCell<T>



impl<T> !Freeze for OnceCell<T>



impl<T> !Freeze for RefCell<T>



impl<T> !Freeze for SyncUnsafeCell<T>



impl<T> !Freeze for UnsafePinned<T>



impl<T> Freeze for Align1<T>
where T: Freeze,



impl<T> Freeze for Align2<T>
where T: Freeze,



impl<T> Freeze for Align4<T>
where T: Freeze,



impl<T> Freeze for Align8<T>
where T: Freeze,



impl<T> Freeze for AssertUnwindSafe<T>
where T: Freeze,



impl<T> Freeze for Bound<T>
where T: Freeze,



impl<T> Freeze for Complex<T>
where T: Freeze,



impl<T> Freeze for CopyOnDrop<T>



impl<T> Freeze for Cursor<T>
where T: Freeze,



impl<T> Freeze for Discriminant<T>



impl<T> Freeze for core::iter::sources::empty::Empty<T>
where PhantomData<fn() -> T>: Freeze,



impl<T> Freeze for GapGuard<T>



impl<T> Freeze for GapGuardRaw<T>
where *mut T: Freeze,



impl<T> Freeze for core::result::IntoIter<T>
where Option<T>: Freeze,



impl<T> Freeze for ManuallyDrop<T>
where MaybeDangling<T>: Freeze, T: ?Sized,



impl<T> Freeze for MaybeSizedValue<T>
where PhantomData<T>: Freeze, T: ?Sized,



impl<T> Freeze for MaybeUninit<T>
where ManuallyDrop<T>: Freeze,



impl<T> Freeze for MergeState<T>
where *mut T: Freeze,



impl<T> Freeze for NeverShortCircuit<T>
where T: Freeze,



impl<T> Freeze for NonNull<T>
where *const T is !null: Freeze, T: ?Sized,



impl<T> Freeze for NumBuffer<T>



impl<T> Freeze for Once<T>
where IntoIter<T>: Freeze,



impl<T> Freeze for Option<T>
where T: Freeze,



impl<T> Freeze for core::slice::sort::stable::quicksort::PartitionState<T>



impl<T> Freeze for core::slice::sort::unstable::quicksort::PartitionState<T>



impl<T> Freeze for Pending<T>
where PhantomData<fn() -> T>: Freeze,



impl<T> Freeze for PhantomContravariant<T>
where PhantomData<fn(T)>: Freeze, T: ?Sized,



impl<T> Freeze for PhantomCovariant<T>
where PhantomData<fn() -> T>: Freeze, T: ?Sized,



impl<T> Freeze for PhantomInvariant<T>
where PhantomData<fn(T) -> T>: Freeze, T: ?Sized,



impl<T> Freeze for Poll<T>
where T: Freeze,



impl<T> Freeze for Ready<T>
where Option<T>: Freeze,



impl<T> Freeze for RepeatNInner<T>
where T: Freeze,



impl<T> Freeze for Rev<T>
where T: Freeze,



impl<T> Freeze for Reverse<T>
where T: Freeze,



impl<T> Freeze for Saturating<T>
where T: Freeze,



impl<T> Freeze for SyncView<T>
where T: Freeze + ?Sized,



impl<T> Freeze for core::io::util::Take<T>
where T: Freeze,



impl<T> Freeze for TraitImpl<T>
where DynMetadata<T>: Freeze, T: ?Sized,



impl<T> Freeze for Unaligned<T>
where T: Freeze,



impl<T> Freeze for Value<T>
where PhantomData<T>: Freeze,



impl<T> Freeze for Wrapper<T>
where T: Freeze,



impl<T> Freeze for Wrapping<T>
where T: Freeze,



impl<T> Freeze for Yeet<T>
where T: Freeze,



impl<Y, R> Freeze for CoroutineState<Y, R>
where Y: Freeze, R: Freeze,



impl<const LEN: usize> Freeze for SimdShuffleIdx<LEN>
where [u32; LEN]: Freeze,



impl<const N: usize, ESCAPING> Freeze for EscapeIterInner<N, ESCAPING>



impl<const N: usize> Freeze for MaybeEscapedCharacter<N>
where [AsciiChar; N]: Freeze,