Send

Trait Send 

1.6.0 · Source
pub unsafe auto trait Send { }
Types that can be transferred across thread boundaries.

This trait is automatically implemented when the compiler determines it’s appropriate.

An example of a non-Send type is the reference-counting pointer rc::Rc. If two threads attempt to clone Rcs that point to the same reference-counted value, they might try to update the reference count at the same time, which is undefined behavior because Rc doesn’t use atomic operations. Its cousin sync::Arc does use atomic operations (incurring some overhead) and thus is Send.

See the Nomicon and the Sync trait for more details.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.0.0 · Source

impl !Send for Arguments<'_>

Source

impl !Send for LocalWaker

Source

impl Send for core::ffi::c_str::Bytes<'_>

Source

impl Send for Custom

Source

impl Send for CustomOwner

1.10.0 · Source

impl Send for Location<'_>

Source

impl Send for Repr

Source

impl Send for ResumeTy

1.0.0 · Source

impl Send for TypeId

1.36.0 · Source

impl Send for Waker

1.44.0 · Source

impl<'a> Send for core::io::io_slice::IoSlice<'a>

1.44.0 · Source

impl<'a> Send for core::io::io_slice::IoSliceMut<'a>

Source

impl<Dyn: PointeeSized> Send for DynMetadata<Dyn>

1.0.0 · Source

impl<T: AtomicPrimitive> Send for Atomic<T>

1.0.0 · Source

impl<T: PointeeSized> !Send for *const T

1.0.0 · Source

impl<T: PointeeSized> !Send for *mut T

1.25.0 · Source

impl<T: PointeeSized> !Send for NonNull<T>

NonNull pointers are not Send because the data they reference may be aliased.

Source

impl<T: Send + PointeeSized> Send for Unique<T>

Unique pointers are Send if T is Send because the data they reference is unaliased. Note that this aliasing invariant is unenforced by the type system; the abstraction using the Unique must enforce it.

1.0.0 · Source

impl<T: Send> Send for core::slice::iter::IterMut<'_, T>

1.0.0 · Source

impl<T: Sync + PointeeSized> Send for &T

1.0.0 · Source

impl<T: Sync> Send for core::slice::iter::Iter<'_, T>

1.0.0 · Source

impl<T> Send for Cell<T>
where T: Send + ?Sized,

1.31.0 · Source

impl<T> Send for ChunksExactMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for ChunksMut<'_, T>
where T: Send,

1.28.0 · Source

impl<T> Send for NonZero<T>

1.31.0 · Source

impl<T> Send for RChunksExactMut<'_, T>
where T: Send,

1.31.0 · Source

impl<T> Send for RChunksMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for RefCell<T>
where T: Send + ?Sized,

Auto implementors



impl !Send for RawWaker



impl !Send for VaListInner



impl !Send for iovec



impl Send for Abi



impl Send for AddrKind



impl Send for AddrParseError



impl Send for AesOutput



impl Send for core::mem::alignment::Alignment



impl Send for core::fmt::Alignment



impl Send for AlignmentEnum



impl Send for AllocError



impl Send for AlwaysEscaped



impl Send for Array



impl Send for AsciiChar



impl Send for Assume



impl Send for AtomicOrdering



impl Send for BasicBlock



impl Send for BiasedFp



impl Send for Big8x3



impl Send for Big32x40



impl Send for BorrowError



impl Send for BorrowMutError



impl Send for BorrowedBufDebug



impl Send for ByteNeedle



impl Send for ByteStr



impl Send for BytesIsNotEmpty



impl Send for CStr



impl Send for CaseMappingIter



impl Send for CharCase



impl Send for CharErrorKind



impl Send for CharEscapeDebug



impl Send for CharEscapeDefault



impl Send for CharEscapeUnicode



impl Send for CharTryFromError



impl Send for CodePointInner



impl Send for Const



impl Send for CpuidResult



impl Send for DebugAsHex



impl Send for Decimal



impl Send for DecimalSeq



impl Send for DecodeUtf16Error



impl Send for Decoded



impl Send for Direction



impl Send for DriftsortRun



impl Send for Duration



impl Send for DynTrait



impl Send for DynTraitPredicate



impl Send for core::io::util::Empty



impl Send for EmptyNeedle



impl Send for EncodeKey128Output



impl Send for EncodeKey256Output



impl Send for core::io::error::Error



impl Send for core::fmt::Error



impl Send for ErrorKind



impl Send for EscapeByte



impl Send for core::char::EscapeDebug



impl Send for EscapeDebugExtArgs



impl Send for core::ascii::EscapeDefault



impl Send for core::char::EscapeDefault



impl Send for core::char::EscapeUnicode



impl Send for FieldId



impl Send for FloatErrorKind



impl Send for FnPtr



impl Send for FormattingOptions



impl Send for FpCategory



impl Send for FromBytesUntilNulError



impl Send for FromBytesWithNulError



impl Send for FullDecoded



impl Send for Generic



impl Send for GenericType



impl Send for GetDisjointMutError



impl Send for I32NotAllOnes



impl Send for I64NotAllOnes



impl Send for IndexRange



impl Send for IntErrorKind



impl Send for Internal



impl Send for IpAddr



impl Send for Ipv4Addr



impl Send for Ipv6Addr



impl Send for Ipv6MulticastScope



impl Send for IsAsciiWhitespace



impl Send for IsNotEmpty



impl Send for IsWhitespace



impl Send for L1Lut



impl Send for L2Lut



impl Send for Last



impl Send for Layout



impl Send for LayoutError



impl Send for Lifetime



impl Send for LinesMap



impl Send for Locality



impl Send for MatchOnly



impl Send for MaybeEscaped



impl Send for Nanoseconds



impl Send for NeverShortCircuitResidual



impl Send for NonZeroCharInner



impl Send for NonZeroI8Inner



impl Send for NonZeroI16Inner



impl Send for NonZeroI32Inner



impl Send for NonZeroI64Inner



impl Send for NonZeroI128Inner



impl Send for NonZeroIsizeInner



impl Send for NonZeroU8Inner



impl Send for NonZeroU16Inner



impl Send for NonZeroU32Inner



impl Send for NonZeroU64Inner



impl Send for NonZeroU128Inner



impl Send for NonZeroUsizeInner



impl Send for OneSidedRangeBound



impl Send for core::cmp::Ordering



impl Send for core::sync::atomic::Ordering



impl Send for PadAdapterState



impl Send for ParseBoolError



impl Send for ParseCharError



impl Send for ParseFloatError



impl Send for ParseIntError



impl Send for PhantomPinned



impl Send for Pointer



impl Send for PostPadding



impl Send for core::unicode::unicode_data::conversions::Range



impl Send for RangeFull



impl Send for RawWakerVTable



impl Send for Reference



impl Send for RejectAndMatch



impl Send for core::io::util::Repeat



impl Send for ReturnToArg



impl Send for SearchStep



impl Send for SeekFrom



impl Send for ShortOffsetRunHeader



impl Send for core::num::imp::flt2dec::Sign



impl Send for core::fmt::Sign



impl Send for SimdAlign



impl Send for Sink



impl Send for Sip13Rounds



impl Send for Sip24Rounds



impl Send for SipHasher



impl Send for SipHasher24



impl Send for Slice



impl Send for SocketAddr



impl Send for SocketAddrV4



impl Send for SocketAddrV6



impl Send for core::hash::sip::State



impl Send for Str



impl Send for StrSearcherImpl



impl Send for ToCasefold



impl Send for ToLowercase



impl Send for ToTitlecase



impl Send for ToUppercase



impl Send for Trait



impl Send for TryCaptureWithDebug



impl Send for TryCaptureWithoutDebug



impl Send for TryFromCharError



impl Send for TryFromFloatSecsError



impl Send for TryFromFloatSecsErrorKind



impl Send for TryFromIntError



impl Send for TryFromSliceError



impl Send for TwoWaySearcher



impl Send for Type



impl Send for TypeKind



impl Send for U32NotAllOnes



impl Send for U64NotAllOnes



impl Send for UnsafeBytesToStr



impl Send for UnwindActionArg



impl Send for UnwindTerminateReason



impl Send for UsizeNoHighBit



impl Send for Utf8BoundaryError



impl Send for Utf8Error



impl Send for VariantId



impl Send for WideAesOutput



impl Send for __m128



impl Send for __m256



impl Send for __m512



impl Send for __m128bh



impl Send for __m128d



impl Send for __m128h



impl Send for __m128i



impl Send for __m256bh



impl Send for __m256d



impl Send for __m256h



impl Send for __m256i



impl Send for __m512bh



impl Send for __m512d



impl Send for __m512h



impl Send for __m512i



impl Send for __tile1024i



impl Send for bf16



impl Send for c_void



impl<'a, 'b, const N: usize> Send for CharArrayRefSearcher<'a, 'b, N>
where <MultiCharEqPattern<&'b [char; N]> as Pattern>::Searcher<'a>: Send,



impl<'a, 'b> !Send for DebugInner<'a, 'b>



impl<'a, 'b> !Send for DebugList<'a, 'b>



impl<'a, 'b> !Send for DebugMap<'a, 'b>



impl<'a, 'b> !Send for DebugSet<'a, 'b>



impl<'a, 'b> !Send for DebugStruct<'a, 'b>



impl<'a, 'b> !Send for DebugTuple<'a, 'b>



impl<'a, 'b> Send for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Send for StrSearcher<'a, 'b>



impl<'a, A> Send for core::option::Iter<'a, A>
where Item<&'a A>: Send,



impl<'a, A> Send for core::option::IterMut<'a, A>



impl<'a, C> Send for MultiCharEqSearcher<'a, C>
where C: Send,



impl<'a, F> Send for CharPredicateSearcher<'a, F>



impl<'a, I, R> Send for GenericShunt<'a, I, R>
where I: Send, &'a mut Option<R>: Send,



impl<'a, I> Send for ByRefSized<'a, I>
where &'a mut I: Send,



impl<'a, I> Send for TaggedOption<'a, I>
where Option<<I as Type<'a>>::Reified>: Send,



impl<'a, P> Send for MatchIndices<'a, P>
where MatchIndicesInternal<'a, P>: Send,



impl<'a, P> Send for MatchIndicesInternal<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for Matches<'a, P>
where MatchesInternal<'a, P>: Send,



impl<'a, P> Send for MatchesInternal<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RMatchIndices<'a, P>
where MatchIndicesInternal<'a, P>: Send,



impl<'a, P> Send for RMatches<'a, P>
where MatchesInternal<'a, P>: Send,



impl<'a, P> Send for core::str::iter::RSplit<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, P> Send for core::str::iter::RSplitN<'a, P>
where SplitNInternal<'a, P>: Send,



impl<'a, P> Send for RSplitTerminator<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, P> Send for core::str::iter::Split<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, P> Send for core::str::iter::SplitInclusive<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, P> Send for SplitInternal<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for core::str::iter::SplitN<'a, P>
where SplitNInternal<'a, P>: Send,



impl<'a, P> Send for SplitNInternal<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, P> Send for SplitTerminator<'a, P>
where SplitInternal<'a, P>: Send,



impl<'a, T, P> Send for ChunkBy<'a, T, P>
where &'a [T]: Send, P: Send,



impl<'a, T, P> Send for ChunkByMut<'a, T, P>
where &'a mut [T]: Send, P: Send,



impl<'a, T, P> Send for core::slice::iter::RSplit<'a, T, P>
where Split<'a, T, P>: Send,



impl<'a, T, P> Send for RSplitMut<'a, T, P>
where SplitMut<'a, T, P>: Send,



impl<'a, T, P> Send for core::slice::iter::RSplitN<'a, T, P>
where GenericSplitN<RSplit<'a, T, P>>: Send,



impl<'a, T, P> Send for RSplitNMut<'a, T, P>
where GenericSplitN<RSplitMut<'a, T, P>>: Send,



impl<'a, T, P> Send for core::slice::iter::Split<'a, T, P>
where &'a [T]: Send, P: Send,



impl<'a, T, P> Send for core::slice::iter::SplitInclusive<'a, T, P>
where &'a [T]: Send, P: Send,



impl<'a, T, P> Send for SplitInclusiveMut<'a, T, P>
where &'a mut [T]: Send, P: Send,



impl<'a, T, P> Send for SplitMut<'a, T, P>
where &'a mut [T]: Send, P: Send,



impl<'a, T, P> Send for core::slice::iter::SplitN<'a, T, P>
where GenericSplitN<Split<'a, T, P>>: Send,



impl<'a, T, P> Send for SplitNMut<'a, T, P>
where GenericSplitN<SplitMut<'a, T, P>>: Send,



impl<'a, T, const N: usize> Send for ArrayWindows<'a, T, N>
where &'a [T]: Send,



impl<'a, T> !Send for BorrowedCursor<'a, T>



impl<'a, T> Send for Chunks<'a, T>
where &'a [T]: Send,



impl<'a, T> Send for ChunksExact<'a, T>
where &'a [T]: Send,



impl<'a, T> Send for core::mem::maybe_uninit::Guard<'a, T>
where &'a mut [MaybeUninit<T>]: Send,



impl<'a, T> Send for core::array::Guard<'a, T>
where &'a mut [MaybeUninit<T>]: Send,



impl<'a, T> Send for GuardBack<'a, T>
where &'a mut [MaybeUninit<T>]: Send,



impl<'a, T> Send for InitializingSlice<'a, T>
where &'a mut [MaybeUninit<T>]: Send,



impl<'a, T> Send for core::result::Iter<'a, T>
where Option<&'a T>: Send,



impl<'a, T> Send for core::result::IterMut<'a, T>



impl<'a, T> Send for RChunks<'a, T>
where &'a [T]: Send,



impl<'a, T> Send for RChunksExact<'a, T>
where &'a [T]: Send,



impl<'a, T> Send for Windows<'a, T>
where &'a [T]: Send,



impl<'a, const N: usize> Send for CharArraySearcher<'a, N>



impl<'a> !Send for Argument<'a>



impl<'a> !Send for ArgumentType<'a>



impl<'a> !Send for Context<'a>



impl<'a> !Send for ContextBuilder<'a>



impl<'a> !Send for ExtData<'a>



impl<'a> !Send for Formatter<'a>



impl<'a> !Send for core::io::io_slice::repr::IoSlice<'a>



impl<'a> !Send for core::io::io_slice::repr::IoSliceMut<'a>



impl<'a> !Send for PanicInfo<'a>



impl<'a> !Send for PanicMessage<'a>



impl<'a> !Send for Request<'a>



impl<'a> !Send for Source<'a>



impl<'a> !Send for VaList<'a>



impl<'a> Send for core::str::iter::Bytes<'a>



impl<'a> Send for CharIndices<'a>



impl<'a> Send for CharSearcher<'a>



impl<'a> Send for Chars<'a>



impl<'a> Send for Debug<'a>



impl<'a> Send for DisplayBuffer<'a>



impl<'a> Send for EncodeUtf16<'a>



impl<'a> Send for EscapeAscii<'a>



impl<'a> Send for core::str::iter::EscapeDebug<'a>



impl<'a> Send for core::str::iter::EscapeDefault<'a>



impl<'a> Send for core::str::iter::EscapeUnicode<'a>



impl<'a> Send for Formatted<'a>



impl<'a> Send for Lines<'a>



impl<'a> Send for LinesAny<'a>



impl<'a> Send for Parser<'a>



impl<'a> Send for Part<'a>



impl<'a> Send for PhantomContravariantLifetime<'a>



impl<'a> Send for PhantomCovariantLifetime<'a>



impl<'a> Send for PhantomInvariantLifetime<'a>



impl<'a> Send for core::slice::ascii::SplitAsciiWhitespace<'a>



impl<'a> Send for core::str::iter::SplitAsciiWhitespace<'a>



impl<'a> Send for SplitWhitespace<'a>



impl<'a> Send for Utf8Chunk<'a>



impl<'a> Send for Utf8Chunks<'a>



impl<'a> Send for Utf8Pattern<'a>



impl<'b, T> !Send for core::cell::Ref<'b, T>



impl<'b, T> !Send for RefMut<'b, T>



impl<'b> !Send for BorrowRef<'b>



impl<'b> !Send for BorrowRefMut<'b>



impl<'buf, 'state> !Send for PadAdapter<'buf, 'state>



impl<'data, T> Send for BorrowedBuf<'data, T>
where &'data mut [MaybeUninit<T>]: Send,



impl<'l, 'f, T, F> !Send for Drain<'l, 'f, T, F>



impl<A, B> Send for core::iter::adapters::chain::Chain<A, B>
where Option<A>: Send, Option<B>: Send,



impl<A, B> Send for Zip<A, B>
where A: Send, B: Send,



impl<A> Send for core::option::IntoIter<A>
where Item<A>: Send,



impl<A> Send for Item<A>
where Option<A>: Send,



impl<A> Send for OptionFlatten<A>
where Option<A>: Send,



impl<A> Send for RangeFromIter<A>
where A: Send,



impl<A> Send for RangeInclusiveIter<A>
where RangeInclusive<A>: Send,



impl<A> Send for RangeIter<A>
where Range<A>: Send,



impl<A> Send for core::iter::sources::repeat::Repeat<A>
where A: Send,



impl<A> Send for RepeatN<A>



impl<B, C> Send for ControlFlow<B, C>
where C: Send, B: Send,



impl<C> Send for ErrorData<C>
where C: Send,



impl<C> Send for MultiCharEqPattern<C>
where C: Send,



impl<DATA> Send for PolymorphicIter<DATA>
where DATA: Send + ?Sized,



impl<E, M> Send for Capture<E, M>
where Option<E>: Send, PhantomData<M>: Send,



impl<E> Send for Tagged<E>
where E: Send + ?Sized,



impl<F> Send for DebugOnce<F>
where Cell<Option<F>>: Send,



impl<F> Send for core::iter::sources::from_fn::FromFn<F>
where F: Send,



impl<F> Send for core::fmt::builders::FromFn<F>
where F: Send,



impl<F> Send for MaybeDone<F>
where F: Send, <F as Future>::Output: Send,



impl<F> Send for OnceWith<F>
where Option<F>: Send,



impl<F> Send for PollFn<F>
where F: Send,



impl<F> Send for RepeatWith<F>
where F: Send,



impl<G> Send for FromCoroutine<G>
where G: Send,



impl<H> Send for BuildHasherDefault<H>
where PhantomData<fn() -> H>: Send,



impl<I, F, const N: usize> Send for MapWindows<I, F, N>
where F: Send, MapWindowsInner<I, N>: Send,



impl<I, F> Send for FilterMap<I, F>
where I: Send, F: Send,



impl<I, F> Send for Inspect<I, F>
where I: Send, F: Send,



impl<I, F> Send for Map<I, F>
where I: Send, F: Send,



impl<I, G> Send for IntersperseWith<I, G>
where G: Send, Option<<I as Iterator>::Item>: Send, I: Send,



impl<I, P> Send for Filter<I, P>
where I: Send, P: Send,



impl<I, P> Send for MapWhile<I, P>
where I: Send, P: Send,



impl<I, P> Send for SkipWhile<I, P>
where I: Send, P: Send,



impl<I, P> Send for TakeWhile<I, P>
where I: Send, P: Send,



impl<I, St, F> Send for Scan<I, St, F>
where I: Send, F: Send, St: Send,



impl<I, U, F> Send for FlatMap<I, U, F>
where FlattenCompat<Map<I, F>, <U as IntoIterator>::IntoIter>: Send,



impl<I, U> Send for FlattenCompat<I, U>
where Fuse<I>: Send, Option<U>: Send,



impl<I, const N: usize> Send for ArrayChunks<I, N>
where I: Send, Option<IntoIter<<I as Iterator>::Item, N>>: Send,



impl<I, const N: usize> Send for MapWindowsInner<I, N>
where I: Send, Option<Buffer<<I as Iterator>::Item, N>>: Send,



impl<I> Send for Cloned<I>
where I: Send,



impl<I> Send for Copied<I>
where I: Send,



impl<I> Send for Cycle<I>
where I: Send,



impl<I> Send for DecodeUtf16<I>
where I: Send,



impl<I> Send for Enumerate<I>
where I: Send,



impl<I> Send for Flatten<I>



impl<I> Send for FromIter<I>
where I: Send,



impl<I> Send for Fuse<I>
where Option<I>: Send,



impl<I> Send for GenericSplitN<I>
where I: Send,



impl<I> Send for Intersperse<I>
where <I as Iterator>::Item: Sized + Send, Option<<I as Iterator>::Item>: Send, I: Send,



impl<I> Send for Peekable<I>
where I: Send, Option<Option<<I as Iterator>::Item>>: Send,



impl<I> Send for core::error::tags::Ref<I>
where PhantomData<I>: Send,



impl<I> Send for Skip<I>
where I: Send,



impl<I> Send for StepBy<I>
where I: Send,



impl<I> Send for core::iter::adapters::take::Take<I>
where I: Send,



impl<Idx> Send for Clamp<Idx>
where Idx: Send,



impl<Idx> Send for core::ops::range::Range<Idx>
where Idx: Send,



impl<Idx> Send for core::range::Range<Idx>
where Idx: Send,



impl<Idx> Send for core::ops::range::RangeFrom<Idx>
where Idx: Send,



impl<Idx> Send for core::range::RangeFrom<Idx>
where Idx: Send,



impl<Idx> Send for core::ops::range::RangeInclusive<Idx>
where Idx: Send,



impl<Idx> Send for core::range::RangeInclusive<Idx>
where Idx: Send,



impl<Idx> Send for RangeTo<Idx>
where Idx: Send,



impl<Idx> Send for core::ops::range::RangeToInclusive<Idx>
where Idx: Send,



impl<Idx> Send for core::range::RangeToInclusive<Idx>
where Idx: Send,



impl<K, V> Send for KeyAndValue<K, V>
where K: Send, V: Send,



impl<P> Send for MaybeDangling<P>
where P: Send + ?Sized,



impl<Ptr> Send for Pin<Ptr>
where Ptr: Send,



impl<Ptr> Send for PinHelper<Ptr>
where Ptr: Send,



impl<S> Send for Hasher<S>
where PhantomData<S>: Send,



impl<T, E> Send for Result<T, E>
where T: Send, E: Send,



impl<T, F> Send for DropGuard<T, F>



impl<T, F> Send for LazyCell<T, F>
where UnsafeCell<State<T, F>>: Send,



impl<T, F> Send for core::cell::lazy::State<T, F>
where F: Send, T: Send,



impl<T, F> Send for Successors<T, F>
where Option<T>: Send, F: Send,



impl<T, U> Send for core::io::util::Chain<T, U>
where T: Send, U: Send,



impl<T, const N: usize> Send for AlignedStorage<T, N>
where [T; 0]: Send, [MaybeUninit<u8>; N]: Send,



impl<T, const N: usize> Send for Buffer<T, N>
where [[MaybeUninit<T>; N]; 2]: Send,



impl<T, const N: usize> Send for core::array::iter::IntoIter<T, N>



impl<T, const N: usize> Send for Mask<T, N>
where Simd<T, N>: Send,



impl<T, const N: usize> Send for core::core_arch::simd::Simd<T, N>
where [T; N]: Send,



impl<T, const N: usize> Send for core::core_simd::vector::Simd<T, N>
where [T; N]: Send,



impl<T, const N: usize> Send for SimdM<T, N>
where [T; N]: Send,



impl<T, const VARIANT: u32, const FIELD: u32> Send for FieldRepresentingType<T, VARIANT, FIELD>
where PhantomData<fn(T) -> T>: Send, T: ?Sized,



impl<T> !Send for CopyOnDrop<T>



impl<T> !Send for GapGuard<T>



impl<T> !Send for GapGuardRaw<T>



impl<T> !Send for MergeState<T>



impl<T> !Send for core::slice::sort::stable::quicksort::PartitionState<T>



impl<T> !Send for core::slice::sort::unstable::quicksort::PartitionState<T>



impl<T> Send for Align1<T>
where T: Send,



impl<T> Send for Align2<T>
where T: Send,



impl<T> Send for Align4<T>
where T: Send,



impl<T> Send for Align8<T>
where T: Send,



impl<T> Send for AssertUnwindSafe<T>
where T: Send,



impl<T> Send for Bound<T>
where T: Send,



impl<T> Send for Complex<T>
where T: Send,



impl<T> Send for CovariantUnsafeCell<T>
where UnsafeCell<T>: Send, T: ?Sized,



impl<T> Send for Cursor<T>
where T: Send,



impl<T> Send for Discriminant<T>



impl<T> Send for core::iter::sources::empty::Empty<T>
where PhantomData<fn() -> T>: Send,



impl<T> Send for core::result::IntoIter<T>
where Option<T>: Send,



impl<T> Send for ManuallyDrop<T>
where MaybeDangling<T>: Send, T: ?Sized,



impl<T> Send for MaybeSizedValue<T>
where PhantomData<T>: Send, T: ?Sized,



impl<T> Send for MaybeUninit<T>
where ManuallyDrop<T>: Send,



impl<T> Send for NeverShortCircuit<T>
where T: Send,



impl<T> Send for NumBuffer<T>
where <T as NumBufferTrait>::Buf: Send, PhantomData<T>: Send,



impl<T> Send for Once<T>
where IntoIter<T>: Send,



impl<T> Send for OnceCell<T>
where UnsafeCell<Option<T>>: Send,



impl<T> Send for Option<T>
where T: Send,



impl<T> Send for Pending<T>
where PhantomData<fn() -> T>: Send,



impl<T> Send for PhantomContravariant<T>
where PhantomData<fn(T)>: Send, T: ?Sized,



impl<T> Send for PhantomCovariant<T>
where PhantomData<fn() -> T>: Send, T: ?Sized,



impl<T> Send for PhantomData<T>
where T: ?Sized,



impl<T> Send for PhantomInvariant<T>
where PhantomData<fn(T) -> T>: Send, T: ?Sized,



impl<T> Send for Poll<T>
where T: Send,



impl<T> Send for Ready<T>
where Option<T>: Send,



impl<T> Send for RepeatNInner<T>
where T: Send,



impl<T> Send for Rev<T>
where T: Send,



impl<T> Send for Reverse<T>
where T: Send,



impl<T> Send for Saturating<T>
where T: Send,



impl<T> Send for SyncUnsafeCell<T>
where UnsafeCell<T>: Send, T: ?Sized,



impl<T> Send for SyncView<T>
where T: Send + ?Sized,



impl<T> Send for core::io::util::Take<T>
where T: Send,



impl<T> Send for TraitImpl<T>
where DynMetadata<T>: Send, T: ?Sized,



impl<T> Send for Unaligned<T>
where T: Send,



impl<T> Send for UnsafeCell<T>
where T: Send + ?Sized,



impl<T> Send for UnsafePinned<T>
where UnsafeCell<T>: Send, T: ?Sized,



impl<T> Send for Value<T>
where PhantomData<T>: Send,



impl<T> Send for Wrapper<T>
where T: Send,



impl<T> Send for Wrapping<T>
where T: Send,



impl<T> Send for Yeet<T>
where T: Send,



impl<Y, R> Send for CoroutineState<Y, R>
where Y: Send, R: Send,



impl<const LEN: usize> Send for SimdShuffleIdx<LEN>
where [u32; LEN]: Send,



impl<const N: usize, ESCAPING> Send for EscapeIterInner<N, ESCAPING>



impl<const N: usize> Send for MaybeEscapedCharacter<N>
where [AsciiChar; N]: Send,