Sync

Trait Sync 

1.6.0 · Source
pub unsafe auto trait Sync { }
Types for which it is safe to share references between threads.

This trait is automatically implemented when the compiler determines it’s appropriate.

The precise definition is: a type T is Sync if and only if &T is Send. In other words, if there is no possibility of undefined behavior (including data races) when passing &T references between threads.

As one would expect, primitive types like u8 and f64 are all Sync, and so are simple aggregate types containing them, like tuples, structs and enums. More examples of basic Sync types include “immutable” types like &T, and those with simple inherited mutability, such as Box<T>, Vec<T> and most other collection types. (Generic parameters need to be Sync for their container to be Sync.)

A somewhat surprising consequence of the definition is that &mut T is Sync (if T is Sync) even though it seems like that might provide unsynchronized mutation. The trick is that a mutable reference behind a shared reference (that is, & &mut T) becomes read-only, as if it were a & &T. Hence there is no risk of a data race.

A shorter overview of how Sync and Send relate to referencing:

  • &T is Send if and only if T is Sync
  • &mut T is Send if and only if T is Send
  • &T and &mut T are Sync if and only if T is Sync

Types that are not Sync are those that have “interior mutability” in a non-thread-safe form, such as Cell and RefCell. These types allow for mutation of their contents even through an immutable, shared reference. For example the set method on Cell<T> takes &self, so it requires only a shared reference &Cell<T>. The method performs no synchronization, thus Cell cannot be Sync.

Another example of a non-Sync type is the reference-counting pointer Rc. Given any reference &Rc<T>, you can clone a new Rc<T>, modifying the reference counts in a non-atomic way.

For cases when one does need thread-safe interior mutability, Rust provides atomic data types, as well as explicit locking via sync::Mutex and sync::RwLock. These types ensure that any mutation cannot cause data races, hence the types are Sync. Likewise, sync::Arc provides a thread-safe analogue of Rc.

Any types with interior mutability must also use the cell::UnsafeCell wrapper around the value(s) which can be mutated through a shared reference. Failing to doing this is undefined behavior. For example, transmute-ing from &T to &mut T is invalid.

See the Nomicon for more details about Sync.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.0.0 · Source

impl !Sync for Arguments<'_>

Source

impl !Sync for LocalWaker

Source

impl Sync for core::ffi::c_str::Bytes<'_>

Source

impl Sync for Custom

Source

impl Sync for CustomOwner

1.10.0 · Source

impl Sync for Location<'_>

Source

impl Sync for Repr

Source

impl Sync for ResumeTy

1.0.0 · Source

impl Sync for TypeId

1.36.0 · Source

impl Sync for Waker

1.44.0 · Source

impl<'a> Sync for core::io::io_slice::IoSlice<'a>

1.44.0 · Source

impl<'a> Sync for core::io::io_slice::IoSliceMut<'a>

Source

impl<Dyn: PointeeSized> Sync for DynMetadata<Dyn>

Source

impl<T: ?Sized + Sync> Sync for SyncUnsafeCell<T>

Source

impl<T: ?Sized + Sync> Sync for UnsafePinned<T>

1.0.0 · Source

impl<T: ?Sized> !Sync for Cell<T>

1.0.0 · Source

impl<T: ?Sized> !Sync for RefCell<T>

1.0.0 · Source

impl<T: ?Sized> !Sync for UnsafeCell<T>

Source

impl<T: ?Sized> Sync for SyncView<T>

1.0.0 · Source

impl<T: AtomicPrimitive> Sync for Atomic<T>

1.0.0 · Source

impl<T: PointeeSized> !Sync for *const T

1.0.0 · Source

impl<T: PointeeSized> !Sync for *mut T

1.25.0 · Source

impl<T: PointeeSized> !Sync for NonNull<T>

NonNull pointers are not Sync because the data they reference may be aliased.

Source

impl<T: Sync + PointeeSized> Sync for Unique<T>

Unique pointers are Sync if T is Sync because the data they reference is unaliased. Note that this aliasing invariant is unenforced by the type system; the abstraction using the Unique must enforce it.

1.0.0 · Source

impl<T: Sync> Sync for core::slice::iter::Iter<'_, T>

1.0.0 · Source

impl<T: Sync> Sync for core::slice::iter::IterMut<'_, T>

1.70.0 · Source

impl<T> !Sync for OnceCell<T>

1.31.0 · Source

impl<T> Sync for ChunksExactMut<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Sync for ChunksMut<'_, T>
where T: Sync,

1.28.0 · Source

impl<T> Sync for NonZero<T>

1.31.0 · Source

impl<T> Sync for RChunksExactMut<'_, T>
where T: Sync,

1.31.0 · Source

impl<T> Sync for RChunksMut<'_, T>
where T: Sync,

Auto implementors



impl !Sync for RawWaker



impl !Sync for VaListInner



impl !Sync for iovec



impl Sync for !



impl Sync for ()



impl Sync for Abi



impl Sync for AddrKind



impl Sync for AddrParseError



impl Sync for AesOutput



impl Sync for core::mem::alignment::Alignment



impl Sync for core::fmt::Alignment



impl Sync for AlignmentEnum



impl Sync for AllocError



impl Sync for AlwaysEscaped



impl Sync for Array



impl Sync for AsciiChar



impl Sync for Assume



impl Sync for AtomicOrdering



impl Sync for BasicBlock



impl Sync for BiasedFp



impl Sync for Big8x3



impl Sync for Big32x40



impl Sync for Bool



impl Sync for BorrowError



impl Sync for BorrowMutError



impl Sync for ByteStr



impl Sync for BytesIsNotEmpty



impl Sync for CStr



impl Sync for CaseMappingIter



impl Sync for Char



impl Sync for CharCase



impl Sync for CharErrorKind



impl Sync for CharEscapeDebugContinue



impl Sync for CharEscapeDefault



impl Sync for CharEscapeUnicode



impl Sync for CharTryFromError



impl Sync for CodePointInner



impl Sync for Const



impl Sync for CpuidResult



impl Sync for DebugAsHex



impl Sync for Decimal



impl Sync for DecimalSeq



impl Sync for DecodeUtf16Error



impl Sync for Decoded



impl Sync for Direction



impl Sync for DriftsortRun



impl Sync for Duration



impl Sync for DynTrait



impl Sync for DynTraitPredicate



impl Sync for core::io::util::Empty



impl Sync for EmptyNeedle



impl Sync for EncodeKey128Output



impl Sync for EncodeKey256Output



impl Sync for Enum



impl Sync for core::io::error::Error



impl Sync for core::fmt::Error



impl Sync for ErrorKind



impl Sync for EscapeByte



impl Sync for core::char::EscapeDebug



impl Sync for EscapeDebugExtArgs



impl Sync for core::ascii::EscapeDefault



impl Sync for core::char::EscapeDefault



impl Sync for core::char::EscapeUnicode



impl Sync for Field



impl Sync for FieldId



impl Sync for Float



impl Sync for FloatErrorKind



impl Sync for FnPtr



impl Sync for FormattingOptions



impl Sync for FpCategory



impl Sync for FromBytesUntilNulError



impl Sync for FromBytesWithNulError



impl Sync for FullDecoded



impl Sync for Generic



impl Sync for GenericType



impl Sync for GetDisjointMutError



impl Sync for I32NotAllOnes



impl Sync for I64NotAllOnes



impl Sync for IndexRange



impl Sync for Infallible



impl Sync for Int



impl Sync for IntErrorKind



impl Sync for Internal



impl Sync for IpAddr



impl Sync for Ipv4Addr



impl Sync for Ipv6Addr



impl Sync for Ipv6MulticastScope



impl Sync for IsAsciiWhitespace



impl Sync for IsNotEmpty



impl Sync for IsWhitespace



impl Sync for L1Lut



impl Sync for L2Lut



impl Sync for Last



impl Sync for Layout



impl Sync for LayoutError



impl Sync for Lifetime



impl Sync for LinesMap



impl Sync for Locality



impl Sync for MatchOnly



impl Sync for MaybeEscaped



impl Sync for Nanoseconds



impl Sync for NeverShortCircuitResidual



impl Sync for NonZeroCharInner



impl Sync for NonZeroI8Inner



impl Sync for NonZeroI16Inner



impl Sync for NonZeroI32Inner



impl Sync for NonZeroI64Inner



impl Sync for NonZeroI128Inner



impl Sync for NonZeroIsizeInner



impl Sync for NonZeroU8Inner



impl Sync for NonZeroU16Inner



impl Sync for NonZeroU32Inner



impl Sync for NonZeroU64Inner



impl Sync for NonZeroU128Inner



impl Sync for NonZeroUsizeInner



impl Sync for OneSidedRangeBound



impl Sync for core::cmp::Ordering



impl Sync for core::sync::atomic::Ordering



impl Sync for PadAdapterState



impl Sync for ParseBoolError



impl Sync for ParseCharError



impl Sync for ParseFloatError



impl Sync for ParseIntError



impl Sync for PhantomPinned



impl Sync for Pointer



impl Sync for PostPadding



impl Sync for core::unicode::unicode_data::conversions::Range



impl Sync for RangeFull



impl Sync for RawWakerVTable



impl Sync for Reference



impl Sync for RejectAndMatch



impl Sync for core::io::util::Repeat



impl Sync for ReturnToArg



impl Sync for SearchStep



impl Sync for SeekFrom



impl Sync for ShortOffsetRunHeader



impl Sync for core::num::imp::flt2dec::Sign



impl Sync for core::fmt::Sign



impl Sync for SimdAlign



impl Sync for Sink



impl Sync for Sip13Rounds



impl Sync for Sip24Rounds



impl Sync for SipHasher



impl Sync for SipHasher24



impl Sync for Slice



impl Sync for SocketAddr



impl Sync for SocketAddrV4



impl Sync for SocketAddrV6



impl Sync for core::hash::sip::State



impl Sync for Str



impl Sync for StrSearcherImpl



impl Sync for Struct



impl Sync for ToCasefold



impl Sync for ToLowercase



impl Sync for ToTitlecase



impl Sync for ToUppercase



impl Sync for Trait



impl Sync for TryCaptureWithDebug



impl Sync for TryCaptureWithoutDebug



impl Sync for TryFromCharError



impl Sync for TryFromFloatSecsError



impl Sync for TryFromFloatSecsErrorKind



impl Sync for TryFromIntError



impl Sync for TryFromSliceError



impl Sync for Tuple



impl Sync for TwoWaySearcher



impl Sync for Type



impl Sync for TypeKind



impl Sync for U32NotAllOnes



impl Sync for U64NotAllOnes



impl Sync for Union



impl Sync for UnsafeBytesToStr



impl Sync for UnwindActionArg



impl Sync for UnwindTerminateReason



impl Sync for UsizeNoHighBit



impl Sync for Utf8BoundaryError



impl Sync for Utf8Error



impl Sync for Variant



impl Sync for WideAesOutput



impl Sync for __m128



impl Sync for __m256



impl Sync for __m512



impl Sync for __m128bh



impl Sync for __m128d



impl Sync for __m128h



impl Sync for __m128i



impl Sync for __m256bh



impl Sync for __m256d



impl Sync for __m256h



impl Sync for __m256i



impl Sync for __m512bh



impl Sync for __m512d



impl Sync for __m512h



impl Sync for __m512i



impl Sync for __tile1024i



impl Sync for bf16



impl Sync for bool



impl Sync for c_void



impl Sync for char



impl Sync for f16



impl Sync for f32



impl Sync for f64



impl Sync for f128



impl Sync for i8



impl Sync for i16



impl Sync for i32



impl Sync for i64



impl Sync for i128



impl Sync for isize



impl Sync for str



impl Sync for u8



impl Sync for u16



impl Sync for u32



impl Sync for u64



impl Sync for u128



impl Sync for usize



impl<'a, 'b, const N: usize> Sync for CharArrayRefSearcher<'a, 'b, N>



impl<'a, 'b> !Sync for DebugInner<'a, 'b>



impl<'a, 'b> !Sync for DebugList<'a, 'b>



impl<'a, 'b> !Sync for DebugMap<'a, 'b>



impl<'a, 'b> !Sync for DebugSet<'a, 'b>



impl<'a, 'b> !Sync for DebugStruct<'a, 'b>



impl<'a, 'b> !Sync for DebugTuple<'a, 'b>



impl<'a, 'b> Sync for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Sync for StrSearcher<'a, 'b>



impl<'a, A> Sync for core::option::Iter<'a, A>
where A: Sync,



impl<'a, A> Sync for core::option::IterMut<'a, A>
where A: Sync,



impl<'a, C> Sync for MultiCharEqSearcher<'a, C>
where C: Sync,



impl<'a, F> Sync for CharPredicateSearcher<'a, F>
where F: Sync,



impl<'a, I, R> Sync for GenericShunt<'a, I, R>
where I: Sync, R: Sync,



impl<'a, I> Sync for ByRefSized<'a, I>
where I: Sync,



impl<'a, I> Sync for TaggedOption<'a, I>
where <I as Type<'a>>::Reified: Sync,



impl<'a, P> Sync for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for MatchIndicesInternal<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for MatchesInternal<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for core::str::iter::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for core::str::iter::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for core::str::iter::Split<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for core::str::iter::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for SplitInternal<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for core::str::iter::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for SplitNInternal<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, P> Sync for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Sync,



impl<'a, T, P> Sync for ChunkBy<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for ChunkByMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for core::slice::iter::RSplit<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for RSplitMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for core::slice::iter::RSplitN<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for RSplitNMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for core::slice::iter::Split<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for core::slice::iter::SplitInclusive<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitInclusiveMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for core::slice::iter::SplitN<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, P> Sync for SplitNMut<'a, T, P>
where P: Sync, T: Sync,



impl<'a, T, const N: usize> Sync for ArrayWindows<'a, T, N>
where T: Sync,



impl<'a, T> Sync for BorrowedCursor<'a, T>
where T: Sync,



impl<'a, T> Sync for Chunks<'a, T>
where T: Sync,



impl<'a, T> Sync for ChunksExact<'a, T>
where T: Sync,



impl<'a, T> Sync for core::mem::maybe_uninit::Guard<'a, T>
where T: Sync,



impl<'a, T> Sync for core::array::Guard<'a, T>
where T: Sync,



impl<'a, T> Sync for GuardBack<'a, T>
where T: Sync,



impl<'a, T> Sync for InitializingSlice<'a, T>
where T: Sync,



impl<'a, T> Sync for core::result::Iter<'a, T>
where T: Sync,



impl<'a, T> Sync for core::result::IterMut<'a, T>
where T: Sync,



impl<'a, T> Sync for RChunks<'a, T>
where T: Sync,



impl<'a, T> Sync for RChunksExact<'a, T>
where T: Sync,



impl<'a, T> Sync for Windows<'a, T>
where T: Sync,



impl<'a, const N: usize> Sync for CharArraySearcher<'a, N>



impl<'a> !Sync for Argument<'a>



impl<'a> !Sync for ArgumentType<'a>



impl<'a> !Sync for Context<'a>



impl<'a> !Sync for ContextBuilder<'a>



impl<'a> !Sync for ExtData<'a>



impl<'a> !Sync for Formatter<'a>



impl<'a> !Sync for core::io::io_slice::repr::IoSlice<'a>



impl<'a> !Sync for core::io::io_slice::repr::IoSliceMut<'a>



impl<'a> !Sync for PanicInfo<'a>



impl<'a> !Sync for PanicMessage<'a>



impl<'a> !Sync for Request<'a>



impl<'a> !Sync for Source<'a>



impl<'a> !Sync for VaList<'a>



impl<'a> Sync for core::str::iter::Bytes<'a>



impl<'a> Sync for CharIndices<'a>



impl<'a> Sync for CharSearcher<'a>



impl<'a> Sync for Chars<'a>



impl<'a> Sync for Debug<'a>



impl<'a> Sync for EncodeUtf16<'a>



impl<'a> Sync for EscapeAscii<'a>



impl<'a> Sync for core::str::iter::EscapeDebug<'a>



impl<'a> Sync for core::str::iter::EscapeDefault<'a>



impl<'a> Sync for core::str::iter::EscapeUnicode<'a>



impl<'a> Sync for Formatted<'a>



impl<'a> Sync for Lines<'a>



impl<'a> Sync for LinesAny<'a>



impl<'a> Sync for Parser<'a>



impl<'a> Sync for Part<'a>



impl<'a> Sync for PhantomContravariantLifetime<'a>



impl<'a> Sync for PhantomCovariantLifetime<'a>



impl<'a> Sync for PhantomInvariantLifetime<'a>



impl<'a> Sync for SplitAsciiWhitespace<'a>



impl<'a> Sync for SplitWhitespace<'a>



impl<'a> Sync for Utf8Chunk<'a>



impl<'a> Sync for Utf8Chunks<'a>



impl<'a> Sync for Utf8Pattern<'a>



impl<'b, T> !Sync for core::cell::Ref<'b, T>



impl<'b, T> !Sync for RefMut<'b, T>



impl<'b> !Sync for BorrowRef<'b>



impl<'b> !Sync for BorrowRefMut<'b>



impl<'buf, 'state> !Sync for PadAdapter<'buf, 'state>



impl<'data, T> Sync for BorrowedBuf<'data, T>
where T: Sync,



impl<'l, 'f, T, F> !Sync for Drain<'l, 'f, T, F>



impl<A, B> Sync for core::iter::adapters::chain::Chain<A, B>
where A: Sync, B: Sync,



impl<A, B> Sync for Zip<A, B>
where A: Sync, B: Sync,



impl<A> Sync for core::option::IntoIter<A>
where A: Sync,



impl<A> Sync for Item<A>
where A: Sync,



impl<A> Sync for OptionFlatten<A>
where A: Sync,



impl<A> Sync for RangeFromIter<A>
where A: Sync,



impl<A> Sync for RangeInclusiveIter<A>
where A: Sync,



impl<A> Sync for RangeIter<A>
where A: Sync,



impl<A> Sync for core::iter::sources::repeat::Repeat<A>
where A: Sync,



impl<A> Sync for RepeatN<A>
where A: Sync,



impl<B, C> Sync for ControlFlow<B, C>
where C: Sync, B: Sync,



impl<C> Sync for ErrorData<C>
where C: Sync,



impl<C> Sync for MultiCharEqPattern<C>
where C: Sync,



impl<DATA> Sync for PolymorphicIter<DATA>
where DATA: Sync + ?Sized,



impl<E, M> Sync for Capture<E, M>
where E: Sync, M: Sync,



impl<E> Sync for Tagged<E>
where E: Sync + ?Sized,



impl<F> Sync for core::iter::sources::from_fn::FromFn<F>
where F: Sync,



impl<F> Sync for core::fmt::builders::FromFn<F>
where F: Sync,



impl<F> Sync for MaybeDone<F>
where F: Sync, <F as Future>::Output: Sync,



impl<F> Sync for OnceWith<F>
where F: Sync,



impl<F> Sync for PollFn<F>
where F: Sync,



impl<F> Sync for RepeatWith<F>
where F: Sync,



impl<G> Sync for FromCoroutine<G>
where G: Sync,



impl<H> Sync for BuildHasherDefault<H>



impl<I, F, const N: usize> Sync for MapWindows<I, F, N>
where F: Sync, I: Sync, <I as Iterator>::Item: Sync,



impl<I, F> Sync for FilterMap<I, F>
where I: Sync, F: Sync,



impl<I, F> Sync for Inspect<I, F>
where I: Sync, F: Sync,



impl<I, F> Sync for Map<I, F>
where I: Sync, F: Sync,



impl<I, G> Sync for IntersperseWith<I, G>
where G: Sync, I: Sync, <I as Iterator>::Item: Sync,



impl<I, P> Sync for Filter<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for MapWhile<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for SkipWhile<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for TakeWhile<I, P>
where I: Sync, P: Sync,



impl<I, St, F> Sync for Scan<I, St, F>
where I: Sync, F: Sync, St: Sync,



impl<I, U, F> Sync for FlatMap<I, U, F>
where <U as IntoIterator>::IntoIter: Sync, I: Sync, F: Sync,



impl<I, U> Sync for FlattenCompat<I, U>
where U: Sync, I: Sync,



impl<I, const N: usize> Sync for ArrayChunks<I, N>
where I: Sync, <I as Iterator>::Item: Sync,



impl<I, const N: usize> Sync for MapWindowsInner<I, N>
where I: Sync, <I as Iterator>::Item: Sync,



impl<I> Sync for Cloned<I>
where I: Sync,



impl<I> Sync for Copied<I>
where I: Sync,



impl<I> Sync for Cycle<I>
where I: Sync,



impl<I> Sync for DecodeUtf16<I>
where I: Sync,



impl<I> Sync for Enumerate<I>
where I: Sync,



impl<I> Sync for Flatten<I>
where <<I as Iterator>::Item as IntoIterator>::IntoIter: Sync, I: Sync,



impl<I> Sync for FromIter<I>
where I: Sync,



impl<I> Sync for Fuse<I>
where I: Sync,



impl<I> Sync for GenericSplitN<I>
where I: Sync,



impl<I> Sync for Intersperse<I>
where <I as Iterator>::Item: Sized + Sync, I: Sync,



impl<I> Sync for Peekable<I>
where I: Sync, <I as Iterator>::Item: Sync,



impl<I> Sync for core::error::tags::Ref<I>
where I: Sync,



impl<I> Sync for Skip<I>
where I: Sync,



impl<I> Sync for StepBy<I>
where I: Sync,



impl<I> Sync for core::iter::adapters::take::Take<I>
where I: Sync,



impl<Idx> Sync for Clamp<Idx>
where Idx: Sync,



impl<Idx> Sync for core::ops::range::Range<Idx>
where Idx: Sync,



impl<Idx> Sync for core::range::Range<Idx>
where Idx: Sync,



impl<Idx> Sync for core::ops::range::RangeFrom<Idx>
where Idx: Sync,



impl<Idx> Sync for core::range::RangeFrom<Idx>
where Idx: Sync,



impl<Idx> Sync for core::ops::range::RangeInclusive<Idx>
where Idx: Sync,



impl<Idx> Sync for core::range::RangeInclusive<Idx>
where Idx: Sync,



impl<Idx> Sync for RangeTo<Idx>
where Idx: Sync,



impl<Idx> Sync for core::ops::range::RangeToInclusive<Idx>
where Idx: Sync,



impl<Idx> Sync for core::range::RangeToInclusive<Idx>
where Idx: Sync,



impl<P> Sync for MaybeDangling<P>
where P: Sync + ?Sized,



impl<Ptr> Sync for Pin<Ptr>
where Ptr: Sync,



impl<Ptr> Sync for PinHelper<Ptr>
where Ptr: Sync,



impl<Ret, T> Sync for fn(T₁, T₂, …, Tₙ) -> Ret



impl<S> Sync for Hasher<S>
where S: Sync,



impl<T, E> Sync for Result<T, E>
where T: Sync, E: Sync,



impl<T, F = fn() -> T> !Sync for LazyCell<T, F>



impl<T, F> Sync for DropGuard<T, F>
where T: Sync, F: Sync,



impl<T, F> Sync for core::cell::lazy::State<T, F>
where F: Sync, T: Sync,



impl<T, F> Sync for Successors<T, F>
where F: Sync, T: Sync,



impl<T, U> Sync for core::io::util::Chain<T, U>
where T: Sync, U: Sync,



impl<T, const N: usize> Sync for AlignedStorage<T, N>
where T: Sync,



impl<T, const N: usize> Sync for Buffer<T, N>
where T: Sync,



impl<T, const N: usize> Sync for core::array::iter::IntoIter<T, N>
where T: Sync,



impl<T, const N: usize> Sync for Mask<T, N>
where T: Sync,



impl<T, const N: usize> Sync for core::core_arch::simd::Simd<T, N>
where T: Sync,



impl<T, const N: usize> Sync for core::core_simd::vector::Simd<T, N>
where T: Sync,



impl<T, const N: usize> Sync for SimdM<T, N>
where T: Sync,



impl<T, const N: usize> Sync for [MaybeUninit<T>; N]
where T: Sync,



impl<T, const N: usize> Sync for [Option<T>; N]
where T: Sync,



impl<T, const N: usize> Sync for [T; N]
where T: Sync,



impl<T, const VARIANT: u32, const FIELD: u32> Sync for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,



impl<T> !Sync for CopyOnDrop<T>



impl<T> !Sync for GapGuard<T>



impl<T> !Sync for GapGuardRaw<T>



impl<T> !Sync for MergeState<T>



impl<T> !Sync for core::slice::sort::stable::quicksort::PartitionState<T>



impl<T> !Sync for core::slice::sort::unstable::quicksort::PartitionState<T>



impl<T> Sync for (T₁, T₂, …, Tₙ)
where T: Sync,



impl<T> Sync for Align1<T>
where T: Sync,



impl<T> Sync for Align2<T>
where T: Sync,



impl<T> Sync for Align4<T>
where T: Sync,



impl<T> Sync for Align8<T>
where T: Sync,



impl<T> Sync for AssertUnwindSafe<T>
where T: Sync,



impl<T> Sync for Bound<T>
where T: Sync,



impl<T> Sync for Cursor<T>
where T: Sync,



impl<T> Sync for Discriminant<T>



impl<T> Sync for core::iter::sources::empty::Empty<T>



impl<T> Sync for core::result::IntoIter<T>
where T: Sync,



impl<T> Sync for ManuallyDrop<T>
where T: Sync + ?Sized,



impl<T> Sync for MaybeSizedValue<T>
where T: Sync + ?Sized,



impl<T> Sync for MaybeUninit<T>
where T: Sync,



impl<T> Sync for NeverShortCircuit<T>
where T: Sync,



impl<T> Sync for NumBuffer<T>
where <T as NumBufferTrait>::Buf: Sync, T: Sync,



impl<T> Sync for Once<T>
where T: Sync,



impl<T> Sync for Option<T>
where T: Sync,



impl<T> Sync for Pending<T>



impl<T> Sync for PhantomContravariant<T>
where T: ?Sized,



impl<T> Sync for PhantomCovariant<T>
where T: ?Sized,



impl<T> Sync for PhantomData<T>
where T: Sync + ?Sized,



impl<T> Sync for PhantomInvariant<T>
where T: ?Sized,



impl<T> Sync for Poll<T>
where T: Sync,



impl<T> Sync for Ready<T>
where T: Sync,



impl<T> Sync for RepeatNInner<T>
where T: Sync,



impl<T> Sync for Rev<T>
where T: Sync,



impl<T> Sync for Reverse<T>
where T: Sync,



impl<T> Sync for Saturating<T>
where T: Sync,



impl<T> Sync for core::io::util::Take<T>
where T: Sync,



impl<T> Sync for TraitImpl<T>
where T: ?Sized,



impl<T> Sync for Unaligned<T>
where T: Sync,



impl<T> Sync for Value<T>
where T: Sync,



impl<T> Sync for Wrapper<T>
where T: Sync,



impl<T> Sync for Wrapping<T>
where T: Sync,



impl<T> Sync for Yeet<T>
where T: Sync,



impl<T> Sync for [T]
where T: Sync,



impl<Y, R> Sync for CoroutineState<Y, R>
where Y: Sync, R: Sync,



impl<const LEN: usize> Sync for SimdShuffleIdx<LEN>



impl<const N: usize, ESCAPING> Sync for EscapeIterInner<N, ESCAPING>
where ESCAPING: Sync,



impl<const N: usize> Sync for MaybeEscapedCharacter<N>



impl<const N: usize> Sync for [u8; N]



impl<const SIZE: usize> Sync for DisplayBuffer<SIZE>