Send

Trait Send 

1.6.0 · Source
pub unsafe auto trait Send { }
Types that can be transferred across thread boundaries.

This trait is automatically implemented when the compiler determines it’s appropriate.

An example of a non-Send type is the reference-counting pointer rc::Rc. If two threads attempt to clone Rcs that point to the same reference-counted value, they might try to update the reference count at the same time, which is undefined behavior because Rc doesn’t use atomic operations. Its cousin sync::Arc does use atomic operations (incurring some overhead) and thus is Send.

See the Nomicon and the Sync trait for more details.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.0.0 · Source

impl !Send for Arguments<'_>

Source

impl !Send for LocalWaker

1.0.0 · Source

impl<T: PointeeSized> !Send for *const T

1.0.0 · Source

impl<T: PointeeSized> !Send for *mut T

1.25.0 · Source

impl<T: PointeeSized> !Send for NonNull<T>

NonNull pointers are not Send because the data they reference may be aliased.

1.0.0 · Source

impl Send for TypeId

Source

impl Send for core::ffi::c_str::Bytes<'_>

Source

impl Send for ResumeTy

1.10.0 · Source

impl Send for Location<'_>

1.36.0 · Source

impl Send for Waker

Source

impl<Dyn: PointeeSized> Send for DynMetadata<Dyn>

1.0.0 · Source

impl<T> Send for Cell<T>
where T: Send + ?Sized,

1.0.0 · Source

impl<T> Send for RefCell<T>
where T: Send + ?Sized,

1.28.0 · Source

impl<T> Send for NonZero<T>

1.31.0 · Source

impl<T> Send for ChunksExactMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for ChunksMut<'_, T>
where T: Send,

1.31.0 · Source

impl<T> Send for RChunksExactMut<'_, T>
where T: Send,

1.31.0 · Source

impl<T> Send for RChunksMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T: AtomicPrimitive> Send for Atomic<T>

Source

impl<T: Send + PointeeSized> Send for Unique<T>

Unique pointers are Send if T is Send because the data they reference is unaliased. Note that this aliasing invariant is unenforced by the type system; the abstraction using the Unique must enforce it.

1.0.0 · Source

impl<T: Send> Send for core::slice::iter::IterMut<'_, T>

1.0.0 · Source

impl<T: Sync + PointeeSized> Send for &T

1.0.0 · Source

impl<T: Sync> Send for core::slice::iter::Iter<'_, T>

Auto implementors



impl !Send for VaListInner



impl !Send for RawWaker



impl<'a> !Send for ArgumentType<'a>



impl<'a> !Send for ExtData<'a>



impl<'a> !Send for Request<'a>



impl<'a> !Send for Source<'a>



impl<'a> !Send for VaList<'a>



impl<'a> !Send for Argument<'a>



impl<'a> !Send for Formatter<'a>



impl<'a> !Send for PanicInfo<'a>



impl<'a> !Send for PanicMessage<'a>



impl<'a> !Send for Context<'a>



impl<'a> !Send for ContextBuilder<'a>



impl<'a, 'b> !Send for DebugInner<'a, 'b>



impl<'a, 'b> !Send for DebugList<'a, 'b>



impl<'a, 'b> !Send for DebugMap<'a, 'b>



impl<'a, 'b> !Send for DebugSet<'a, 'b>



impl<'a, 'b> !Send for DebugStruct<'a, 'b>



impl<'a, 'b> !Send for DebugTuple<'a, 'b>



impl<'b> !Send for BorrowRef<'b>



impl<'b> !Send for BorrowRefMut<'b>



impl<'b, T> !Send for core::cell::Ref<'b, T>



impl<'b, T> !Send for RefMut<'b, T>



impl<'buf, 'state> !Send for PadAdapter<'buf, 'state>



impl<'l, 'f, T, F> !Send for Drain<'l, 'f, T, F>



impl<T> !Send for CopyOnDrop<T>



impl<T> !Send for MergeState<T>



impl<T> !Send for core::slice::sort::stable::quicksort::PartitionState<T>



impl<T> !Send for GapGuard<T>



impl<T> !Send for GapGuardRaw<T>



impl<T> !Send for core::slice::sort::unstable::quicksort::PartitionState<T>



impl Send for AsciiChar



impl Send for CharErrorKind



impl Send for CharCase



impl Send for core::cmp::Ordering



impl Send for Infallible



impl Send for FromBytesWithNulError



impl Send for c_void



impl Send for core::fmt::Alignment



impl Send for DebugAsHex



impl Send for core::fmt::Sign



impl Send for Locality



impl Send for AtomicOrdering



impl Send for BasicBlock



impl Send for UnwindTerminateReason



impl Send for SimdAlign



impl Send for ErrorKind



impl Send for AlignmentEnum



impl Send for Abi



impl Send for Generic



impl Send for TypeKind



impl Send for IpAddr



impl Send for Ipv6MulticastScope



impl Send for AddrKind



impl Send for SocketAddr



impl Send for FpCategory



impl Send for IntErrorKind



impl Send for FloatErrorKind



impl Send for FullDecoded



impl Send for core::num::imp::flt2dec::Sign



impl Send for OneSidedRangeBound



impl Send for NeverShortCircuitResidual



impl Send for Direction



impl Send for GetDisjointMutError



impl Send for MatchOnly



impl Send for RejectAndMatch



impl Send for SearchStep



impl Send for StrSearcherImpl



impl Send for core::sync::atomic::Ordering



impl Send for TryFromFloatSecsErrorKind



impl Send for Utf8BoundaryError



impl Send for bool



impl Send for char



impl Send for f16



impl Send for f32



impl Send for f64



impl Send for f128



impl Send for i8



impl Send for i16



impl Send for i32



impl Send for i64



impl Send for i128



impl Send for isize



impl Send for !



impl Send for str



impl Send for u8



impl Send for u16



impl Send for u32



impl Send for u64



impl Send for u128



impl Send for ()



impl Send for usize



impl Send for Layout



impl Send for LayoutError



impl Send for AllocError



impl Send for TryFromSliceError



impl Send for core::ascii::EscapeDefault



impl Send for TryCaptureWithDebug



impl Send for TryCaptureWithoutDebug



impl Send for ByteStr



impl Send for BorrowError



impl Send for BorrowMutError



impl Send for CharTryFromError



impl Send for ParseCharError



impl Send for DecodeUtf16Error



impl Send for EscapeDebugExtArgs



impl Send for CaseMappingIter



impl Send for core::char::EscapeDebug



impl Send for core::char::EscapeDefault



impl Send for core::char::EscapeUnicode



impl Send for ToLowercase



impl Send for ToTitlecase



impl Send for ToUppercase



impl Send for TryFromCharError



impl Send for CpuidResult



impl Send for AesOutput



impl Send for EncodeKey128Output



impl Send for EncodeKey256Output



impl Send for WideAesOutput



impl Send for __m128



impl Send for __m128bh



impl Send for __m128d



impl Send for __m128h



impl Send for __m128i



impl Send for __m256



impl Send for __m256bh



impl Send for __m256d



impl Send for __m256h



impl Send for __m256i



impl Send for __m512



impl Send for __m512bh



impl Send for __m512d



impl Send for __m512h



impl Send for __m512i



impl Send for bf16



impl Send for Internal



impl Send for AlwaysEscaped



impl Send for MaybeEscaped



impl Send for CStr



impl Send for FromBytesUntilNulError



impl Send for PadAdapterState



impl Send for Error



impl Send for FormattingOptions



impl Send for PostPadding



impl Send for Sip13Rounds



impl Send for Sip24Rounds



impl Send for SipHasher24



impl Send for SipHasher



impl Send for core::hash::sip::State



impl Send for Last



impl Send for ReturnToArg



impl Send for UnwindActionArg



impl Send for core::io::util::Empty



impl Send for core::io::util::Repeat



impl Send for Sink



impl Send for core::mem::alignment::Alignment



impl Send for Assume



impl Send for Array



impl Send for Bool



impl Send for Char



impl Send for Const



impl Send for DynTrait



impl Send for DynTraitPredicate



impl Send for Enum



impl Send for Field



impl Send for FieldId



impl Send for Float



impl Send for FnPtr



impl Send for GenericType



impl Send for Int



impl Send for Lifetime



impl Send for Pointer



impl Send for Reference



impl Send for Slice



impl Send for Str



impl Send for Struct



impl Send for Trait



impl Send for Tuple



impl Send for Type



impl Send for Union



impl Send for Variant



impl Send for Ipv4Addr



impl Send for Ipv6Addr



impl Send for AddrParseError



impl Send for SocketAddrV4



impl Send for SocketAddrV6



impl Send for ParseIntError



impl Send for TryFromIntError



impl Send for ParseFloatError



impl Send for Big32x40



impl Send for Big8x3



impl Send for BiasedFp



impl Send for Decimal



impl Send for DecimalSeq



impl Send for Decoded



impl Send for CodePointInner



impl Send for I32NotAllOnes



impl Send for I64NotAllOnes



impl Send for Nanoseconds



impl Send for NonZeroCharInner



impl Send for NonZeroI8Inner



impl Send for NonZeroI16Inner



impl Send for NonZeroI32Inner



impl Send for NonZeroI64Inner



impl Send for NonZeroI128Inner



impl Send for NonZeroIsizeInner



impl Send for NonZeroU8Inner



impl Send for NonZeroU16Inner



impl Send for NonZeroU32Inner



impl Send for NonZeroU64Inner



impl Send for NonZeroU128Inner



impl Send for NonZeroUsizeInner



impl Send for U32NotAllOnes



impl Send for U64NotAllOnes



impl Send for UsizeNoHighBit



impl Send for IndexRange



impl Send for RangeFull



impl Send for EscapeByte



impl Send for DriftsortRun



impl Send for ParseBoolError



impl Send for Utf8Error



impl Send for EmptyNeedle



impl Send for TwoWaySearcher



impl Send for BytesIsNotEmpty



impl Send for CharEscapeDebugContinue



impl Send for CharEscapeDefault



impl Send for CharEscapeUnicode



impl Send for IsAsciiWhitespace



impl Send for IsNotEmpty



impl Send for IsWhitespace



impl Send for LinesMap



impl Send for UnsafeBytesToStr



impl Send for RawWakerVTable



impl Send for Duration



impl Send for TryFromFloatSecsError



impl Send for L1Lut



impl Send for L2Lut



impl Send for core::unicode::unicode_data::conversions::Range



impl Send for ShortOffsetRunHeader



impl Send for PhantomPinned



impl<'a> Send for Part<'a>



impl<'a> Send for Utf8Pattern<'a>



impl<'a> Send for BorrowedCursor<'a>



impl<'a> Send for Parser<'a>



impl<'a> Send for Formatted<'a>



impl<'a> Send for EscapeAscii<'a>



impl<'a> Send for core::str::iter::Bytes<'a>



impl<'a> Send for CharIndices<'a>



impl<'a> Send for Chars<'a>



impl<'a> Send for EncodeUtf16<'a>



impl<'a> Send for core::str::iter::EscapeDebug<'a>



impl<'a> Send for core::str::iter::EscapeDefault<'a>



impl<'a> Send for core::str::iter::EscapeUnicode<'a>



impl<'a> Send for Lines<'a>



impl<'a> Send for LinesAny<'a>



impl<'a> Send for SplitAsciiWhitespace<'a>



impl<'a> Send for SplitWhitespace<'a>



impl<'a> Send for Debug<'a>



impl<'a> Send for Utf8Chunk<'a>



impl<'a> Send for Utf8Chunks<'a>



impl<'a> Send for CharSearcher<'a>



impl<'a> Send for PhantomContravariantLifetime<'a>



impl<'a> Send for PhantomCovariantLifetime<'a>



impl<'a> Send for PhantomInvariantLifetime<'a>



impl<'a, 'b> Send for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Send for StrSearcher<'a, 'b>



impl<'a, 'b, const N: usize> Send for CharArrayRefSearcher<'a, 'b, N>



impl<'a, A> Send for core::option::Iter<'a, A>
where A: Sync,



impl<'a, A> Send for core::option::IterMut<'a, A>
where A: Send,



impl<'a, C> Send for MultiCharEqSearcher<'a, C>
where C: Send,



impl<'a, F> Send for CharPredicateSearcher<'a, F>
where F: Send,



impl<'a, I> Send for TaggedOption<'a, I>
where <I as Type<'a>>::Reified: Send,



impl<'a, I> Send for ByRefSized<'a, I>
where I: Send,



impl<'a, I, R> Send for GenericShunt<'a, I, R>
where I: Send, R: Send,



impl<'a, P> Send for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for MatchIndicesInternal<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for MatchesInternal<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for core::str::iter::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for core::str::iter::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for core::str::iter::Split<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for core::str::iter::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for SplitInternal<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for core::str::iter::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for SplitNInternal<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, T> Send for core::array::Guard<'a, T>
where T: Send,



impl<'a, T> Send for InitializingSlice<'a, T>
where T: Send,



impl<'a, T> Send for core::mem::maybe_uninit::Guard<'a, T>
where T: Send,



impl<'a, T> Send for core::result::Iter<'a, T>
where T: Sync,



impl<'a, T> Send for core::result::IterMut<'a, T>
where T: Send,



impl<'a, T> Send for Chunks<'a, T>
where T: Sync,



impl<'a, T> Send for ChunksExact<'a, T>
where T: Sync,



impl<'a, T> Send for RChunks<'a, T>
where T: Sync,



impl<'a, T> Send for RChunksExact<'a, T>
where T: Sync,



impl<'a, T> Send for Windows<'a, T>
where T: Sync,



impl<'a, T, P> Send for ChunkBy<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for ChunkByMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for core::slice::iter::RSplit<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for RSplitMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for core::slice::iter::RSplitN<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for RSplitNMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for core::slice::iter::Split<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for core::slice::iter::SplitInclusive<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for SplitInclusiveMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for SplitMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for core::slice::iter::SplitN<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for SplitNMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, const N: usize> Send for ArrayWindows<'a, T, N>
where T: Sync,



impl<'a, const N: usize> Send for CharArraySearcher<'a, N>



impl<'data> Send for BorrowedBuf<'data>



impl<A> Send for core::iter::sources::repeat::Repeat<A>
where A: Send,



impl<A> Send for RepeatN<A>
where A: Send,



impl<A> Send for core::option::IntoIter<A>
where A: Send,



impl<A> Send for Item<A>
where A: Send,



impl<A> Send for OptionFlatten<A>
where A: Send,



impl<A> Send for RangeFromIter<A>
where A: Send,



impl<A> Send for RangeInclusiveIter<A>
where A: Send,



impl<A> Send for RangeIter<A>
where A: Send,



impl<A, B> Send for core::iter::adapters::chain::Chain<A, B>
where A: Send, B: Send,



impl<A, B> Send for Zip<A, B>
where A: Send, B: Send,



impl<B, C> Send for ControlFlow<B, C>
where C: Send, B: Send,



impl<C> Send for MultiCharEqPattern<C>
where C: Send,



impl<DATA> Send for PolymorphicIter<DATA>
where DATA: Send + ?Sized,



impl<E> Send for Tagged<E>
where E: Send + ?Sized,



impl<E, M> Send for Capture<E, M>
where E: Send, M: Send,



impl<F> Send for MaybeDone<F>
where F: Send, <F as Future>::Output: Send,



impl<F> Send for core::fmt::builders::FromFn<F>
where F: Send,



impl<F> Send for PollFn<F>
where F: Send,



impl<F> Send for core::iter::sources::from_fn::FromFn<F>
where F: Send,



impl<F> Send for OnceWith<F>
where F: Send,



impl<F> Send for RepeatWith<F>
where F: Send,



impl<G> Send for FromCoroutine<G>
where G: Send,



impl<H> Send for BuildHasherDefault<H>



impl<I> Send for FromIter<I>
where I: Send,



impl<I> Send for DecodeUtf16<I>
where I: Send,



impl<I> Send for core::error::tags::Ref<I>
where I: Send,



impl<I> Send for Cloned<I>
where I: Send,



impl<I> Send for Copied<I>
where I: Send,



impl<I> Send for Cycle<I>
where I: Send,



impl<I> Send for Enumerate<I>
where I: Send,



impl<I> Send for Flatten<I>
where <<I as Iterator>::Item as IntoIterator>::IntoIter: Send, I: Send,



impl<I> Send for Fuse<I>
where I: Send,



impl<I> Send for Intersperse<I>
where <I as Iterator>::Item: Sized + Send, I: Send,



impl<I> Send for Peekable<I>
where I: Send, <I as Iterator>::Item: Send,



impl<I> Send for Skip<I>
where I: Send,



impl<I> Send for StepBy<I>
where I: Send,



impl<I> Send for core::iter::adapters::take::Take<I>
where I: Send,



impl<I> Send for GenericSplitN<I>
where I: Send,



impl<I, F> Send for FilterMap<I, F>
where I: Send, F: Send,



impl<I, F> Send for Inspect<I, F>
where I: Send, F: Send,



impl<I, F> Send for Map<I, F>
where I: Send, F: Send,



impl<I, F, const N: usize> Send for MapWindows<I, F, N>
where F: Send, I: Send, <I as Iterator>::Item: Send,



impl<I, G> Send for IntersperseWith<I, G>
where G: Send, I: Send, <I as Iterator>::Item: Send,



impl<I, P> Send for Filter<I, P>
where I: Send, P: Send,



impl<I, P> Send for MapWhile<I, P>
where I: Send, P: Send,



impl<I, P> Send for SkipWhile<I, P>
where I: Send, P: Send,



impl<I, P> Send for TakeWhile<I, P>
where I: Send, P: Send,



impl<I, St, F> Send for Scan<I, St, F>
where I: Send, F: Send, St: Send,



impl<I, U> Send for FlattenCompat<I, U>
where U: Send, I: Send,



impl<I, U, F> Send for FlatMap<I, U, F>
where <U as IntoIterator>::IntoIter: Send, I: Send, F: Send,



impl<I, const N: usize> Send for ArrayChunks<I, N>
where I: Send, <I as Iterator>::Item: Send,



impl<I, const N: usize> Send for MapWindowsInner<I, N>
where I: Send, <I as Iterator>::Item: Send,



impl<Idx> Send for Clamp<Idx>
where Idx: Send,



impl<Idx> Send for core::ops::range::Range<Idx>
where Idx: Send,



impl<Idx> Send for core::ops::range::RangeFrom<Idx>
where Idx: Send,



impl<Idx> Send for core::ops::range::RangeInclusive<Idx>
where Idx: Send,



impl<Idx> Send for RangeTo<Idx>
where Idx: Send,



impl<Idx> Send for core::ops::range::RangeToInclusive<Idx>
where Idx: Send,



impl<Idx> Send for core::range::Range<Idx>
where Idx: Send,



impl<Idx> Send for core::range::RangeFrom<Idx>
where Idx: Send,



impl<Idx> Send for core::range::RangeInclusive<Idx>
where Idx: Send,



impl<Idx> Send for core::range::RangeToInclusive<Idx>
where Idx: Send,



impl<P> Send for MaybeDangling<P>
where P: Send + ?Sized,



impl<Ptr> Send for PinHelper<Ptr>
where Ptr: Send,



impl<Ptr> Send for Pin<Ptr>
where Ptr: Send,



impl<Ret, T> Send for fn(T₁, T₂, …, Tₙ) -> Ret



impl<S> Send for Hasher<S>
where S: Send,



impl<T> Send for Bound<T>
where T: Send,



impl<T> Send for Option<T>
where T: Send,



impl<T> Send for Poll<T>
where T: Send,



impl<T> Send for [T]
where T: Send,



impl<T> Send for (T₁, T₂, …, Tₙ)
where T: Send,



impl<T> Send for Wrapper<T>
where T: Send,



impl<T> Send for OnceCell<T>
where T: Send,



impl<T> Send for SyncUnsafeCell<T>
where T: Send + ?Sized,



impl<T> Send for UnsafeCell<T>
where T: Send + ?Sized,



impl<T> Send for Reverse<T>
where T: Send,



impl<T> Send for MaybeSizedValue<T>
where T: Send + ?Sized,



impl<T> Send for Value<T>
where T: Send,



impl<T> Send for NumBuffer<T>
where T: Send,



impl<T> Send for Pending<T>



impl<T> Send for Ready<T>
where T: Send,



impl<T> Send for Cursor<T>
where T: Send,



impl<T> Send for core::io::util::Take<T>
where T: Send,



impl<T> Send for Rev<T>
where T: Send,



impl<T> Send for core::iter::sources::empty::Empty<T>



impl<T> Send for Once<T>
where T: Send,



impl<T> Send for RepeatNInner<T>
where T: Send,



impl<T> Send for ManuallyDrop<T>
where T: Send + ?Sized,



impl<T> Send for Discriminant<T>



impl<T> Send for TraitImpl<T>
where T: ?Sized,



impl<T> Send for Saturating<T>
where T: Send,



impl<T> Send for Wrapping<T>
where T: Send,



impl<T> Send for NeverShortCircuit<T>
where T: Send,



impl<T> Send for Yeet<T>
where T: Send,



impl<T> Send for AssertUnwindSafe<T>
where T: Send,



impl<T> Send for UnsafePinned<T>
where T: Send + ?Sized,



impl<T> Send for core::result::IntoIter<T>
where T: Send,



impl<T> Send for Align1<T>
where T: Send,



impl<T> Send for Align2<T>
where T: Send,



impl<T> Send for Align4<T>
where T: Send,



impl<T> Send for Align8<T>
where T: Send,



impl<T> Send for SyncView<T>
where T: Send + ?Sized,



impl<T> Send for PhantomData<T>
where T: Send + ?Sized,



impl<T> Send for PhantomContravariant<T>
where T: ?Sized,



impl<T> Send for PhantomCovariant<T>
where T: ?Sized,



impl<T> Send for PhantomInvariant<T>
where T: ?Sized,



impl<T> Send for MaybeUninit<T>
where T: Send,



impl<T, E> Send for Result<T, E>
where T: Send, E: Send,



impl<T, F> Send for core::cell::lazy::State<T, F>
where F: Send, T: Send,



impl<T, F> Send for LazyCell<T, F>
where F: Send, T: Send,



impl<T, F> Send for Successors<T, F>
where F: Send, T: Send,



impl<T, F> Send for DropGuard<T, F>
where T: Send, F: Send,



impl<T, U> Send for core::io::util::Chain<T, U>
where T: Send, U: Send,



impl<T, const N: usize> Send for [T; N]
where T: Send,



impl<T, const N: usize> Send for core::array::iter::IntoIter<T, N>
where T: Send,



impl<T, const N: usize> Send for core::core_arch::simd::Simd<T, N>
where T: Send,



impl<T, const N: usize> Send for SimdM<T, N>
where T: Send,



impl<T, const N: usize> Send for Mask<T, N>
where T: Send,



impl<T, const N: usize> Send for core::core_simd::vector::Simd<T, N>
where T: Send,



impl<T, const N: usize> Send for Buffer<T, N>
where T: Send,



impl<T, const N: usize> Send for AlignedStorage<T, N>
where T: Send,



impl<T, const N: usize> Send for [Option<T>; N]
where T: Send,



impl<T, const N: usize> Send for [MaybeUninit<T>; N]
where T: Send,



impl<T, const VARIANT: u32, const FIELD: u32> Send for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,



impl<Y, R> Send for CoroutineState<Y, R>
where Y: Send, R: Send,



impl<const LEN: usize> Send for SimdShuffleIdx<LEN>



impl<const N: usize> Send for MaybeEscapedCharacter<N>



impl<const N: usize> Send for [u8; N]



impl<const N: usize, ESCAPING> Send for EscapeIterInner<N, ESCAPING>
where ESCAPING: Send,



impl<const SIZE: usize> Send for DisplayBuffer<SIZE>